--------------------------------------------------
-- Bug 46519 Submitted - U firmy Tlapnet není možné stornovat pokladní doklad -> FIXOPIA 
--------------------------------------------------
CREATE OR REPLACE FUNCTION svyrobnicisloupdate()
  RETURNS trigger AS
$BODY$   
declare
  _mnozMj numeric(19,6);
  _datVyst date;
  _idPolSkladV integer;
  _idDoklSkladV integer; 
  _idDoklSkladP integer;
  _kurzDokladuV numeric(19,6);
  _sumZklVysl numeric(19,6);
  _sumZklMenVysl numeric(19,6);
  _sklFifo boolean;
  _cenaMjP numeric(19,6);
  _cenaMjVysl numeric(19,6);
  _koeficient integer;
  _pomoc record;
begin
  --#1 aktualizace FIFO vazeb
  --pouziti vyrobniho cisla na skladove polozce
  if(NEW.idPolSkladVydej is not null and OLD.idPolSkladVydej is null) then
    insert into sfifovazby(idpolskladprijem,    idpolskladvydej,    kusu,idvyrobnicislo)
    values (NEW.idPolSkladPrijem,NEW.idPolSkladVydej,1,   NEW.idvyrobnicislo);

  --nepouziti vyrobniho cisla na skladove polozce
  elsif (NEW.idPolSkladVydej is null and OLD.idPolSkladVydej is not null) then
    -- pokud se idPolSkladVydej nastavi na null z nejake hodnoty musi se smazat i fifo vazba s timto vyrobnim cislem  
    delete from sfifovazby where idvyrobnicislo = NEW.idVyrobniCislo;
  end if;

  _idPolSkladV = coalesce(NEW.idPolSkladVydej, OLD.idPolSkladVydej);    
  select datVyst, mnozMj, idDoklSklad into _datVyst, _mnozMj, _idDoklSkladV from dpolsklad where idpolsklad = _idPolSkladV;

    --#2 vypocet sum, ceny dle vsech vyrobnich cisel pouzitych na skladove polozce (pouze FIFO)  
    _sklfifo := (select isfifosklad(_datVyst));
    --polozka nemusi existovat
    if(_datVyst is not null and _sklFifo and _mnozMj <> 0.0) then
      _sumZklVysl := 0.0;
      _sumZklMenVysl := 0.0;
      _cenaMjVysl := 0.0;
      
      for _pomoc in (select ps.sumZkl, ps.mnozMj, fv.idvyrobnicislo, fv.idpolskladvydej, ps.iddoklsklad 
                      from dpolsklad ps 
                      join sfifovazby fv on fv.idPolSkladPrijem = ps.idPolSklad
                      join ddoklsklad ds on ps.iddoklsklad = ds.iddoklsklad
                      where idvyrobnicislo is not null and fv.idpolskladvydej = _idPolSkladV)
      loop 
        _cenaMjP := _pomoc.sumZkl / _pomoc.mnozMj;
        _sumZklVysl = _sumZklVysl + _cenaMjP;
        _cenaMjVysl = _sumZklVysl / _mnozMj;
      end loop;
      
      --prepocet podle kurzu
      _KurzDokladuV := (select getKurzFromDoklad(_idDoklSkladV, _datVyst));
      if (_kurzDokladuV <> 1.0) then
        _sumZklMenVysl := _sumZklVysl * _kurzDokladuV;
      end if;

      --koeficient      
      if(_mnozMj < 0.0) then
        _koeficient := -1;
        _cenaMjVysl := _koeficient * _cenaMjVysl;
        _sumZklVysl := _koeficient * _sumZklVysl;
        _sumZklMenVysl := _koeficient * _sumZklMenVysl;
      end if;
 
      update dpolsklad set 
        lastUpdate = LOCALTIMESTAMP,
        sumZkl = _sumZklVysl,
        sumZklMen = _sumZklMenVysl,
        cenaMj = _cenaMjVysl,
        cenaMjPoriz = _cenaMjVysl
        where idpolsklad = _idPolSkladV;
    end if;

  execute sprepoctisumydokladu(_idDoklSkladV);
  return NEW;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION svyrobnicisloupdate() OWNER TO %firmaRole%;

 -- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 1081, 't', %appVersion%, clock_timestamp());
