--------------------------------------------------
-- Bug 43737 - Nekonečná rekurze ve funkci dGetStavNaSkladeAktualni pro rekurzivní sady a komplety - could not advance using next()

-- operator <@ since 8.2 
--------------------------------------------------
CREATE OR REPLACE FUNCTION checkrekurzecenik(_idcenik integer, _idceniks integer[]) returns void
language plpgsql 
as $$
DECLARE
  _i integer;
  _id integer;
  _ids integer[];
  _copy boolean;
BEGIN
  _copy := false;

  for _i in array_lower(_idceniks, 1) .. array_upper(_idceniks, 1) loop
    _id := _idceniks[_i];
    
    if (_id = _idcenik) then
      _copy := true;
    end if;

    if _copy then
      _ids := _ids || _id;
    end if;
    
  end loop;
  
  if array_upper(_ids, 1) > 0 then
    raise exception '0012: Definice sad obsahuje cyklickou zavislost na ceste::%', array_to_string(array(select kod from ccenik where idcenik = any(_ids)), ', ');
  end if;
  
END;
$$;
ALTER FUNCTION public.checkrekurzecenik(integer, integer[]) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION dgetstavnaskladeaktualni(i_idcenik integer, i_idsklad integer, i_datum date, _idceniks integer[])
  RETURNS numeric AS
$$       
declare      
  _iducetniobdobi integer;  
  _stavMj numeric(19,6);      
  _idSkladKarty integer;  
  _sadaItemCount integer;  
  _polozkaSady record;  
  _stavSkladuSady numeric(19,6);  
  _pocetPozadavku numeric(19,6);
  _skladove boolean; 
begin      
  -- zjistim jestli nahodu dany cenik neni sada nebo komplet  
  select count(*) into _sadaItemCount from csady where idceniksada = i_idCenik and idcenik <> csady.idceniksada;  
  if(_sadaItemCount = 0) then
    -- pokud se nejedna o sadu tak funguju normalne  
    select skladove into _skladove from ccenik where idcenik = i_idcenik;
    if(_skladove) then
      -- zkusime vypocitat stav na vrcholu  
      select idUcetObdobi into _iducetniobdobi from nUcetObdobi where platiOdData <= i_datum and platiDoData >= i_datum;
      select idKarty into _idSkladKarty from sKarty where idCenik = i_idCenik and idSkladu = i_idsklad and idUcetObdobi = _iducetniobdobi;  
      select stavMj into _stavMj from skarty where idkarty = _idSkladKarty;  
      select sum(mnozMjPlan) into _pocetPozadavku from dpolsklad where mnozMjPlan <> 0.0 and mnozMj = 0.0 and idkarty = _idSkladKarty and storno = false;
      if(_pocetPozadavku is not null) then
        _stavMj = _stavMj - _pocetPozadavku;
      end if;
    else  
      _stavMj = 9999999999999.0; -- vic uz pretejka
    end if;
  else
    --pokud se jedna o sadu spoustim rekurzi
    for _polozkaSady in  
      select * from cSady where idCenikSada = i_idCenik and cSady.idcenik <> cSady.idceniksada  
    loop  
      perform checkrekurzecenik(i_idcenik, _idceniks);
      select dGetStavNaSkladeAktualni(_polozkaSady.idCenik, i_idsklad, i_datum, _idceniks || i_idcenik) into _stavSkladuSady;
      if(_polozkaSady.mnozMj <> 0) then
        _stavSkladuSady = _stavSkladuSady / _polozkaSady.mnozMj;
        if(_stavMj is null) then  
          _stavMj = 9999999999999.0; -- vic uz pretejka  
        end if;  
        select minValue(_stavMj, _stavSkladuSady) into _stavMj;  
      end if;
    end loop;  
  end if;   
   
  -- muze se stat ze _stavMj je null a to znamena ze na sklade nic neni   
  if(_stavMj is null) then   
    _stavMj := 0;   
  end if;   
     
  RETURN _stavMj;       
end       
$$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dgetstavnaskladeaktualni(integer, integer, date, integer[]) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION dgetstavnaskladeaktualni(i_idcenik integer, i_idsklad integer, i_datum date)
  RETURNS numeric AS
$$
declare
  _stavMj numeric(19,6);
begin
  _stavMj := (select dgetstavnaskladeaktualni(i_idcenik, i_idsklad, i_datum, array[-1]));
  return _stavMj;
end;
$$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dgetstavnaskladeaktualni(integer, integer, date) OWNER TO %firmaRole%;


CREATE OR REPLACE FUNCTION dgetstavnasklade(i_skladkartaid integer, i_datum date, i_polskladid integer, i_sarze character varying, i_expirace date, i_typPohybuK character varying, _idceniks integer[])
  RETURNS numeric AS
$$      
declare     
  _pocMj numeric(19,6);     
  _obratMj numeric(19,6);     
  _stavMj numeric(19,6);     
  _idcenik integer;   
  _idskladu integer;   
  _typPohybuK character varying(50);   
  _sadaItemCount integer; 
  _polozkaSady record; 
  _idSkladKarty integer; 
  _iducetniobdobi integer; 
  _idPolSklad integer; 
  _stavSkladuSady numeric(19,6); 
  _mnozMj numeric(19,6); 
  _stavMjKarty numeric(19,6); 
  _rozpadlaPolSklad record; 
begin     
  SELECT pocatMj INTO _pocMj     
  FROM sKarty     
  WHERE idKarty = i_skladkartaid;     
     
  if (i_datum is null) then     
    raise exception '0005:dGetStavNaSklade : Vstupni parametr datum je null.';      
  end if;   
   
  _typPohybuK := i_typPohybuK;   
  --if (i_polskladid >= 0) then   
  --  select typPohybuK into _typPohybuK from ddoklsklad    
  --    where iddoklsklad = (select iddoklsklad from dpolsklad where idpolsklad = i_polskladid);   
  --end if;   
   
  select idcenik, idskladu, iducetobdobi into _idcenik, _idskladu, _iducetniobdobi from skarty where idkarty = i_skladkartaid; 
 
  -- zjistim jestli nahodu dany cenik neni sada nebo komplet 
  select count(*) into _sadaItemCount from csady where idceniksada = _idCenik; 
  -- pokud se nejedna o sadu tak funguju normalne 
  if(_sadaItemCount = 0) then 
    if ((i_sarze is null or i_sarze = '') and i_expirace is null) then    
      -- zkusime zjistit stav skladu k datu 
      if (i_polSkladId < 0) then       
        SELECT sum(CASE ds.typPohybuK WHEN 'typPohybu.prijem' THEN ps.mnozMj ELSE -ps.mnozMj END) INTO _obratMj       
        FROM dPolSklad ps LEFT OUTER JOIN dDoklSklad ds ON ps.idDoklSklad = ds.idDoklSklad       
        WHERE idkarty = i_skladkartaid AND ps.storno <> true AND ps.datSklad <= i_datum;       
      else       
        SELECT sum(CASE ds.typPohybuK WHEN 'typPohybu.prijem' THEN ps.mnozMj ELSE -ps.mnozMj END) INTO _obratMj       
        FROM dPolSklad ps LEFT OUTER JOIN dDoklSklad ds ON ps.idDoklSklad = ds.idDoklSklad       
        WHERE idkarty = i_skladkartaid AND ps.storno <> true AND (ps.datSklad < i_datum OR (ps.datSklad = i_datum AND ps.idPolSklad < i_polskladid));       
      end if;    
      if(_obratMj is null) then _obratMj = 0.0; end if;       
      if(_pocMj is null) then _pocMj = 0.0; end if;        
      _stavMj = _pocMj + _obratMj;     
      -- zkusime vypocitat stav na vrcholu 
      select stavMj into _stavMjKarty from skarty where idkarty = i_skladkartaid; 
      _mnozMj = 0.0; 
      if(i_polSkladId >= 0) then 
        select mnozMj into _mnozMj from dPolSklad where idPolSklad = i_polSkladId; 
      end if;
      for _rozpadlaPolSklad in (select * from dPolSklad where idPolSklad in  
        (select idpolskladcil from svazbypolsklad where idpolskladzdroj = i_polSkladId))  
      loop  
        _mnozMj = _mnozMj + _rozpadlaPolSklad.mnozMj; 
      end loop; 
      if(_typPohybuK = 'typPohybu.vydej') then 
        _stavMjKarty = _stavMjKarty + _mnozMj; 
      else 
        _stavMjKarty = _stavMjKarty - _mnozMj; 
      end if; 
      
      -- spravna hodnota dle bugu 21375 minimum z obou hodnot 
      if(_typPohybuK = 'typPohybu.vydej') then 
        select minValue(_stavMj, _stavMjKarty) into _stavMj; 
      end if;
    else    
      if ((i_sarze is not null and i_sarze <> '') and (i_expirace is null)) then    
        --raise exception 'idCenik = % and idSkladu = %', _idCenik, _idSkladu;   
       
        select sum(pocet) into _stavMj from dpolskladf where idcenik = _idcenik and idskladu = _idskladu and sarze = i_sarze;    
      elsif ((i_sarze is null or i_sarze = '') and (i_expirace is not null)) then    
        select sum(pocet) into _stavMj from dpolskladf where idcenik = _idcenik and idskladu = _idskladu and expirace = i_expirace;    
      else    
        select sum(pocet) into _stavMj from dpolskladf where idcenik = _idcenik and idskladu = _idskladu and sarze = i_sarze and expirace = i_expirace;    
      end if;    
      if (_typPohybuK is not null and _typPohybuK = 'typPohybu.prijem') then    
        select coalesce(sum(mnozMj), 0.0) into _obratMj from dpolsklad where idpolsklad = i_polskladid;    
        if(_stavMj is null) then    
          _stavMj := -_obratMj;    
        else    
          _stavMj := _stavMj - _obratMj;    
        end if;    
      elsif (_typPohybuK is not null and _typPohybuK = 'typPohybu.vydej') then    
        select coalesce(sum(mnozMj), 0.0) into _obratMj from dpolsklad where idpolsklad = i_polskladid;    
        if(_stavMj is null) then    
          _stavMj := _obratMj;    
        else    
          _stavMj := _stavMj + _obratMj;    
        end if;    
      end if;    
    end if;   
  else 
    for _polozkaSady in 
      select * from cSady where idCenikSada = _idCenik 
    loop 
      select idKarty into _idSkladKarty from sKarty where idCenik = _polozkaSady.idCenik and idSkladu = _idskladu and idUcetObdobi = _iducetniobdobi; 
      if(_idSkladKarty is not null) then  
        if(_stavMj is null) then 
          _stavMj = 9999999999999.0; -- vic uz pretejka 
        end if; 
        _idPolSklad = -1; 
        --TODO nejak doresit _idPolSklad, sarze a expirace; 
        perform checkrekurzecenik(_idcenik, _idceniks);
        select dgetstavnasklade(_idSkladKarty, i_datum, -1, i_sarze, i_expirace, _typPohybuK, _idceniks || _idcenik) into _stavSkladuSady; 
        _stavSkladuSady = _stavSkladuSady / _polozkaSady.mnozMj; 
	if(i_polskladid > 0) then 
	  select mnozMj into _mnozMj from dPolSklad where idPolSklad = i_polSkladId; 
          _stavSkladuSady = _stavSkladuSady + (_mnozMj/_polozkaSady.mnozMj); 
        end if; 
        select minValue(_stavMj, _stavSkladuSady) into _stavMj; 
      end if; 
    end loop; 
  end if;  
  
  -- muze se stat ze _stavMj je null a to znamena ze na sklade nic neni  
  if(_stavMj is null) then  
    _stavMj := 0;  
  end if;  
    
  RETURN _stavMj;      
end      
$$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dgetstavnasklade(integer, date, integer, character varying, date, character varying, integer[]) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION dgetstavnasklade(i_skladkartaid integer, i_datum date, i_polskladid integer, i_sarze character varying, i_expirace date, i_typPohybuK character varying)
  RETURNS numeric AS
$$      
declare
  _stavMj numeric(19,6);
begin
  _stavMj := (select dgetstavnasklade(i_skladkartaid, i_datum, i_polskladid, i_sarze, i_expirace, i_typPohybuK, array[-1]));
  return _stavMj;
end;
$$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dgetstavnasklade(integer, date, integer, character varying, date, character varying) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION dgetstavnaskladeaktualni(i_idcenik integer, i_idsklad integer, i_datum date,
 i_idfirma integer, i_iddoklobch integer[], i_novyDoklad boolean, _idceniks integer[])
  RETURNS numeric AS $$
declare
  _stavMj numeric(19,6); 
  _firmaRezerMj numeric(19,6); 
  _celkemRezerMj numeric(19,6); 

  _issada integer;
  _sada record;
  _pomoc numeric(19,6);
  _skladove boolean;
begin
  -- pokud je ceník sadou chceme řešit všechny součásti
  select count(*) into _issada from csady where idceniksada = i_idcenik and csady.idcenik <> csady.idceniksada;
  if(_issada > 0) then
    _stavMj = 9999999999999.0; -- vic uz pretejka 
    select skladove into _skladove from ccenik where idcenik = i_idcenik; 
    if(_skladove) then 
      for _sada in select * from csady where idceniksada = i_idcenik and csady.idcenik <> csady.idceniksada loop
        perform checkrekurzecenik(i_idcenik, _idceniks);
        select dgetstavnaskladeaktualni(_sada.idcenik, i_idsklad, i_datum, i_idfirma, i_iddoklobch, i_novydoklad, _idceniks || i_idcenik) into _pomoc;
        if(_sada.mnozMj != 0.0) then
          _pomoc = _pomoc / _sada.mnozMj;
        end if;
        _stavMj = minValue(_stavMj, _pomoc); 
      end loop;
      return _stavMj;
    end if;
  end if;

  SELECT dgetstavnaskladeaktualni(i_idcenik, i_idsklad, i_datum) INTO _stavMj; 
  
  -- zjistime kolik je celkem rezervovano - od/do ignorujeme (bug 25844, 25789), muselo by se zohlednovat uz pri plneni pole skladmj a nebo toto pole idealne vyhodit
  select coalesce(sum(skladmj), 0) into _celkemRezerMj from srezervace where idcenik = i_idcenik and idsklad = i_idsklad;
   
  IF (i_idfirma > 0) THEN 
    -- array_upper - zjištění délky pole
    -- podmínka - viz možný obsah i_iddoklobch v hlavičce metody, Posgtgresu se pole indexují od 1 -> [1]
    IF ((array_upper(i_iddoklobch,1) = 1 and i_iddoklobch[1] > 0) or array_upper(i_iddoklobch,1) > 1) THEN 
        -- zjistime kolik ma firma rezervovano  
        -- fce any - pro hledání "in array"
        select coalesce(sum(r.skladmj), 0) into _firmaRezerMj from srezervace r 
            left join dpolobch po on r.idpolobch = po.idpolobch
            where r.idfirmy = i_idfirma and r.idcenik = i_idcenik and r.idsklad = i_idsklad and (po.iddoklobch is null or po.iddoklobch  = any(i_iddoklobch)); 
    ELSIF (i_novyDoklad) THEN
            -- jedná se o novou objednávku - zjistime kolik ma firma rezervovano, ale v tomto pripade jen rezervace bez dokladu
        select coalesce(sum(r.skladmj), 0) into _firmaRezerMj from srezervace r  
            left join dpolobch po on r.idpolobch = po.idpolobch 
            where r.idfirmy = i_idfirma and r.idcenik = i_idcenik and r.idsklad = i_idsklad and po.iddoklobch is null;  
    ELSE
        select coalesce(sum(skladmj), 0) into _firmaRezerMj from srezervace where idfirmy = i_idfirma and idcenik = i_idcenik and idsklad = i_idsklad; 
    END IF;
  ELSE 
    _firmaRezerMj := 0; 
  END IF; 
   
  -- spocteme kolik mu muzeme dat 
  _stavMj := minValue(_stavMj, maxValue(_stavMj - _celkemRezerMj, 0) + _firmaRezerMj); 
   
  RETURN _stavMj; 
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.dgetstavnaskladeaktualni(integer, integer, date, integer, integer[],boolean, integer[]) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION dgetstavnaskladeaktualni(i_idcenik integer, i_idsklad integer, i_datum date,
 i_idfirma integer, i_iddoklobch integer[], i_novyDoklad boolean)
  RETURNS numeric AS $$
declare
  _stavMj numeric(19,6);
begin
  _stavMj := (select dgetstavnaskladeaktualni(i_idcenik, i_idsklad, i_datum, i_idfirma, i_iddoklobch, i_novyDoklad, array[-1]));
  return _stavMj;
end;
$$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION public.dgetstavnaskladeaktualni(integer, integer, date, integer, integer[],boolean) OWNER TO %firmaRole%;


 -- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 1095, 't', %appVersion%, clock_timestamp());