-------------------------------------------------------
-- Bug 15978 – [WinStrom] Použití apostrofu sestřelí našeptávač
-------------------------------------------------------

CREATE OR REPLACE FUNCTION findmatcheditems(i_text character varying, i_table character varying,
  i_pkcolumn character varying, i_kodcolumn character varying, i_nazevcolumn character varying, i_nazevL10nColumn character varying,
  i_condClause character varying, i_orderClause character varying, i_startIndex integer, i_pageSize integer)
  RETURNS refcursor AS $$
DECLARE
  _text character varying;
  _nazevL10nColumn character varying;
  _condEmptyNazevL10n character varying;
  _condNotEmptyNazevL10n character varying;
  _condClause character varying;
  _orderClause character varying;
  _query character varying;
  _limit integer;
  _nalezeno integer;
  _zaznam Record;
  _navratoveHodnoty refcursor;
BEGIN
  DROP TABLE IF EXISTS matcheditems;

  CREATE TEMPORARY TABLE matcheditems (
    id integer PRIMARY KEY,
    kod character varying(255),
    nazev text,
    nazevL10n text,
    txt text,
    uroven integer
  ) WITH (OIDS=FALSE);

  _text = UPPER(i_text);
  _text = replace(_text, '''', '''''');   -- je potreba nahradit ' za ''
  _limit = i_startIndex + i_pageSize;

  IF (i_nazevL10nColumn IS NOT NULL) THEN
    _nazevL10nColumn = i_nazevL10nColumn;
  ELSE
    _nazevL10nColumn = 'null';
  END IF;

  IF (i_condClause IS NOT NULL) THEN
    _condClause = i_condClause || ' AND ';
  ELSE
    _condClause = '';
  END IF;

  IF (i_orderClause IS NOT NULL) THEN
    _orderClause = i_orderClause;
  ELSE
    _orderClause = i_nazevcolumn;
  END IF;

  _condEmptyNazevL10n = '(' || _nazevL10nColumn || ' IS NULL OR ' || _nazevL10nColumn || ' = '''')';
  _condNotEmptyNazevL10n = '(' || _nazevL10nColumn || ' IS NOT NULL AND ' || _nazevL10nColumn || ' <> '''')';

  --RAISE NOTICE 'Text is %', _text;

  -- 1) shoda na kód
  EXECUTE 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
      'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
      ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || i_nazevcolumn || ', '': '' || ' || i_nazevcolumn || '), ' || i_nazevcolumn || '), ' ||
      ' 1' ||
      ' FROM ' || i_table ||
      ' WHERE ' || _condClause ||
      ' UPPER(' || i_kodcolumn || ') = ''' || _text || ''' AND ' ||
      i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
      ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';

  SELECT count(*) INTO _nalezeno FROM matcheditems;
  _limit = i_startIndex + i_pageSize - _nalezeno;

  IF (_limit > 0) THEN
    -- 2) shoda na název
    _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
        'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
        ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || i_nazevcolumn || ', '': '' || ' || i_nazevcolumn || '), ' || i_nazevcolumn || '), ' ||
        ' 2' ||
        ' FROM ' || i_table ||
        ' WHERE ' || _condClause ||
        ' ( ' ||
        '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') = ''' || _text || ''') ' ||
        '   OR ' ||
        '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') = ''' || _text || ''') ' ||
        ' ) ' ||
        ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
        ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
    --RAISE NOTICE 'Query is %', _query ;
    EXECUTE _query;

    SELECT count(*) INTO _nalezeno FROM matcheditems;
    _limit = i_startIndex + i_pageSize - _nalezeno;

    IF (_limit > 0) THEN
      -- 3) shodný prefix kódu nebo názvu
      _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
          'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
          ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || i_nazevcolumn || ', '': '' || ' || i_nazevcolumn || '), ' || i_nazevcolumn || '), ' ||
          ' 3' ||
          ' FROM ' || i_table ||
          ' WHERE ' || _condClause ||
          ' ( ' ||
          '   UPPER(' || i_kodcolumn || ') LIKE ''' || _text || '%''' ||
          '   OR ' ||
          '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') LIKE ''' || _text || '%'') ' ||
          '   OR ' ||
          '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') LIKE ''' || _text || '%'') ' ||
          ' ) ' ||
           ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
          ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
      --RAISE NOTICE 'Query is %', _query ;
      EXECUTE _query;

      SELECT count(*) INTO _nalezeno FROM matcheditems;
      _limit = i_startIndex + i_pageSize - _nalezeno;

      IF (_limit > 0) THEN
        -- 4) shodný infix kódu nebo názvu
        _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
            'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
            ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || i_nazevcolumn || ', '': '' || ' || i_nazevcolumn || '), ' || i_nazevcolumn || '), ' ||
            ' 4' ||
            ' FROM ' || i_table ||
            ' WHERE ' || _condClause ||
            ' ( ' ||
            '   UPPER(' || i_kodcolumn || ') LIKE ''%' || _text || '%''' ||
            '   OR ' ||
            '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') LIKE ''%' || _text || '%'') ' ||
            '   OR ' ||
            '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') LIKE ''%' || _text || '%'') ' ||
            ' ) ' ||
            ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
            ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
        --RAISE NOTICE 'Query is %', _query ;
        EXECUTE _query;
      END IF;
    END IF;
  END IF;

  FOR _zaznam IN SELECT * FROM matcheditems LOOP
    IF (_zaznam.nazevL10n IS NOT NULL AND _zaznam.nazevL10n <> '') THEN
      UPDATE matcheditems
      SET txt = COALESCE(NULLIF(_zaznam.kod || ': ' || _zaznam.nazevL10n, ': ' || _zaznam.nazevL10n), _zaznam.nazevL10n)
      WHERE id = _zaznam.id;
    ELSE
      UPDATE matcheditems
      SET txt = COALESCE(NULLIF(_zaznam.kod || ': ' || _zaznam.nazev, ': ' || _zaznam.nazev), _zaznam.nazev)
      WHERE id = _zaznam.id;
    END IF;
  END LOOP;

  --RETURN QUERY SELECT * FROM matcheditems ORDER BY uroven LIMIT i_pageSize OFFSET i_startIndex;
  OPEN _navratoveHodnoty FOR SELECT * FROM matcheditems ORDER BY uroven LIMIT i_pageSize OFFSET i_startIndex;
  RETURN _navratoveHodnoty;
END;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.findmatcheditems(i_text character varying, i_table character varying,
  i_pkcolumn character varying, i_kodcolumn character varying, i_nazevcolumn character varying, i_nazevL10nColumn character varying,
  i_condClause character varying, i_orderClause character varying, i_startIndex integer, i_pageSize integer) OWNER TO %firmaRole%;


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 160, 't');
