------------------------------------------------------------------
-- Bug 17053 – [Winstrom] Lepší rezervace
------------------------------------------------------------------


-- oprava ulozene procedury zjistujici stav skladu, pokud je firma null odecitam od stavu vsechny rezervace
CREATE OR REPLACE FUNCTION dgetstavnasklade(i_skladkartaid integer, i_datum date, i_polskladid integer, i_firmaid integer, i_sarze character varying, i_expirace date)
  RETURNS numeric AS $$
declare
  _sklad integer;
  _cenik integer;
  _stavMj numeric(19,6);
  _firmaRezerMj numeric(19,6);
  _celkemRezerMj numeric(19,6);
begin
  SELECT dgetstavnasklade(i_skladkartaid, i_datum, i_polskladid, i_sarze, i_expirace) INTO _stavMj;
 
  -- vymazeme jiz neplatne rezervace
  delete from srezervace where datumdo is not null and datumdo < date(now());
  -- nacteme si info ze skladove karty
  SELECT idCenik, idTypDokl INTO _cenik, _sklad FROM sKarty WHERE idKarty = i_skladkartaid;
  -- zjistime kolik je celkem rezervovano
  select coalesce(sum(mnozstvi), 0) into _celkemRezerMj from srezervace where idcenik = _cenik and idsklad = _sklad;
  
  IF (i_firmaid > 0) THEN
    -- zjistime kolik ma firma rezervovano
    select coalesce(sum(mnozstvi), 0) into _firmaRezerMj from srezervace where idfirmy = i_firmaid and idcenik = _cenik and idsklad = _sklad;
  ELSE
    _firmaRezerMj := 0;
  END IF;
  
  -- spocteme kolik mu muzeme dat
  _stavMj := minValue(_stavMj, maxValue(_stavMj - _celkemRezerMj, 0) + _firmaRezerMj);
  
  RETURN _stavMj;
end
$$ LANGUAGE plpgsql;


-- pridani funkce na zjisteni stavu skladu, ktera si sama dohleda skladovou kartu
CREATE OR REPLACE FUNCTION dgetstavnasklade(_idCenik integer, _idSklad integer, _datum date, i_polskladid integer, _idFirma integer, i_sarze character varying, i_expirace date)
  RETURNS numeric AS $$
declare
  _idUcetObd integer;
  _idKarty integer;
  _mnozMj numeric(19,6);
begin
  select idUcetObdobi into _idUcetObd from nUcetObdobi where platioddata <= _datum and platidodata >= _datum;
  
  select idkarty into _idKarty from skarty where iducetobdobi = _idUcetObd and idtypdokl = _idSklad and idcenik = _idCenik;

  select dgetstavnasklade(_idKarty, _datum, i_polskladid, _idFirma, i_sarze, i_expirace) into _mnozMj;
  
  return _mnozMj;
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.dgetstavnasklade(integer, integer, date, integer, integer, character varying, date) OWNER TO %firmaRole%;


-- pridani novych sloupcu
ALTER TABLE nnastav ADD COLUMN rezervovatzapor boolean NOT NULL DEFAULT false;
ALTER TABLE nnastav ADD COLUMN rezervovatautom boolean NOT NULL DEFAULT false;
ALTER TABLE dpolobch ADD COLUMN rezervovatmj numeric(19,6) DEFAULT 0.0;

-- doted sli rezervace do zaporu tak to hodime do nastaveni
update nnastav set rezervovatzapor = true;
-- tem co se rezervovali nastavime rezervovane mnozstvi
update dpolobch set rezervovatmj = mnozmj where rezervovat = true and idskladu is not null;


-- funkce pro rezervaci/odrazervaci z polozky obchodu
CREATE OR REPLACE FUNCTION rezervujPolObch(_idCenik integer, _idSklad integer, _idPolObch integer, _mj numeric)
  RETURNS void AS $$
declare
  polObch record;
  _mnoz numeric(19,6);
  _idUcetObd integer;
  _rezer record;
  _idFirma integer;
  _idUziv integer;
begin
  select * into _rezer from srezervace where idPolObch = _idPolObch and idCenik = _idCenik and idSklad = _idSklad;
  
  _mnoz = _mj;
  if _rezer.idrezervace is not null then
    _mnoz = _mnoz + _rezer.mnozstvi;
  end if;
  
  if _mnoz > 0 then             -- pokud ma neco byt zarezervovane
    select * into polObch from dPolObch where idPolObch = _idPolObch;
    
    if _rezer.idrezervace is null then      -- pokud rezervace neexistuje vytvorime ji
      select idFirmy, idUziv into _idFirma, _idUziv from dDoklObch where idDoklObch = polObch.idDoklObch;
      
      insert into srezervace (idpolobch, iduziv, idfirmy, idcenik, idsklad, mnozstvi, datumod)
          values (_idPolObch, _idUziv, _idFirma, _idCenik, _idSklad, _mnoz, now());
    else
      update srezervace set mnozstvi = _mnoz, datumod = polObch.datVyst where idrezervace = _rezer.idRezervace;
    end if;
  else
    if _rezer.idrezervace is not null then    -- pokud rezervace byt nema a je smazeme ji
      delete from srezervace where idrezervace = _rezer.idRezervace;
    end if;
  end if;
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.rezervujPolObch(integer, integer, integer, numeric) OWNER TO %firmaRole%;

DROP FUNCTION rezervujPolObch(integer);


-- trigger volany pri vytvoreni nebo zmene obchodni polozky
CREATE OR REPLACE FUNCTION dpolobchupdaterezer()
  RETURNS trigger AS $$
begin
  if NEW.idSkladu is not null and NEW.rezervovat then
    perform rezervujPolObch(NEW.idCenik, NEW.idSkladu, NEW.idPolObch, NEW.rezervovatMj);
  end if;

  if (tg_op = 'UPDATE') then
    if OLD.idSkladu is not null and OLD.rezervovat then
      perform rezervujPolObch(OLD.idCenik, OLD.idSkladu, OLD.idPolObch, -OLD.rezervovatMj);
    end if;
  end if;
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.dpolobchupdaterezer() OWNER TO %firmaRole%;


-- trigger volany pri zmene obchodniho dokladu, kontroluje zmenu firmy
CREATE OR REPLACE FUNCTION ddoklobchupdaterezer()
  RETURNS trigger AS $$
begin
  if (OLD.idFirmy <> NEW.idFirmy) then
    update srezervace set idFirmy = NEW.idFirmy where idPolObch in (select idPolObch from dPolObch where idDoklObch = NEW.idDoklObch);
  end if;
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.ddoklobchupdaterezer() OWNER TO %firmaRole%;

-- navěšení triggeru na tabulku obchodnich dokladů
CREATE TRIGGER ddoklobchupdaterezer AFTER UPDATE ON ddoklobch
  FOR EACH ROW EXECUTE PROCEDURE ddoklobchupdaterezer();

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 197, 't');
