--------------------------------------------------------------------------------
-- Bug 18293 – [WinStrom] Zamykání období ve mzdách
--------------------------------------------------------------------------------

-- funkce zjistujici zda jsou mzdy zamceny
CREATE OR REPLACE FUNCTION pismzdyzamek(rok integer, mesic integer)
  RETURNS boolean AS $$
declare
  zamku integer;
  calOd date;
  calDo date;
begin
  calOd = date (rok || '-' || mesic || '-01');
  calDo = calOd + interval '1 month' - interval '1 day';
  
  select count(*) into zamku from wzamky where modulmzd = true and zamekk in ('zamek.zamceno', 'zamek.polozamceno') and
    platiOdData <= calDo and platiDoData >= calOd;
  
  return (zamku > 0);
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pismzdyzamek(integer, integer) OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION pcantriggerchangeslozku(_rok integer, _mesic integer, _idosoba integer)
  RETURNS boolean AS $$
declare
  vypocet integer;
  zamku integer;
  calOd date;
  calDo date;
begin
  select count(*) into vypocet from pmzdsloz where idosoba = _idosoba and _rok = rok and _mesic = mesic and
    typslozkyk = 'typSlozky.kopie' and skupslozkyk = 'skupinaSlozky.doba' and datumod is not null;
  
  if (vypocet > 0) then    -- mzda je vypoctena nemuzeme ji menit
    return false;
  end if; 

  return not pismzdyzamek(_rok, _mesic);
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pcantriggerchangeslozku(integer, integer, integer) OWNER TO %firmaRole%;


-- pro zadany pracovni pomer, mesic a rok vygeneruje mzdove slozky
CREATE OR REPLACE FUNCTION pgeneratemzdslozforpracpomandmesic(_idpracpom integer, _rok integer, _mesic integer)
  RETURNS void AS $$
declare
  _datum date;
  _datumpo date;
  _idosoba integer;
  _change boolean;
begin
  _datum = date (_rok || '-' || _mesic || '-01');
  _datumpo = _datum + interval '1 month';
  
  select idosoba, pcantriggerchangeslozku(_rok, _mesic, idosoba) into _idosoba, _change from ppracpomhlav where idpracpomhlav = _idpracpom;

  -- vystupni slozky
  -- jiz se negeneruji, vytvari se pri vypoctu

  if (_change) then  
    -- stale slozky
    perform pupdatemzdslozfromstalasloz(pcreatemzdslozfromcis(idcismzdsloz, _idpracpom, _idosoba, _rok, _mesic), idstalamzdsloz)
      from pstalamzdsloz as S where idpracpom = _idpracpom
        and (datumod is null or (datumod < _datumpo)) and (datumdo is null or (datumdo >= _datum))
        and (select count(*) from pmzdsloz where rok = _rok and mesic = _mesic and idstalamzdsloz = S.idstalamzdsloz) = 0;
  
    -- srazky
    perform pupdatemzdslozfromsrazka(pcreatemzdslozfromcis(idcismzdsloz, null, _idosoba, _rok, _mesic), idsrazka)
      from psrazka as S where idosoba = _idosoba
        and (srazkaod is null or (srazkaod < _datumpo)) and (srazkado is null or (srazkado >= _datum))
        and (select count(*) from pmzdsloz where rok = _rok and mesic = _mesic and idsrazka = S.idsrazka) = 0;
  
    -- odecitatelne polozky
    perform pupdatemzdslozfromodecitpol(pcreatemzdslozfromcis(idcismzdsloz, null, _idosoba, _rok, _mesic), idodecitpol)
      from podecitpol as O where idosoba = _idosoba
        and (platiod is null or (platiod < _datumpo)) and (platido is null or (platido >= _datum))
        and (select count(*) from pmzdsloz where rok = _rok and mesic = _mesic and idodecitpol = O.idodecitpol) = 0;
  end if;
  
  -- smeny
  perform pgeneratesmenyforpracpom(_idpracpom, _rok, _mesic);
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratemzdslozforpracpomandmesic(integer, integer, integer) OWNER TO %firmaRole%;


-- vygeneruje mzdove slozky pro zadany pracovni pomer, pokud je id -1 generuje pro vsechny
CREATE OR REPLACE FUNCTION pgeneratemzdslozforpracpom(_idpracpom integer)
  RETURNS void AS $$
declare
  _od date;
  _do date;
  _odAkt date;
  rokod integer;
  rokdo integer;
  mesicod integer;
  mesicdo integer;
  rokOdAkt integer;
  mesicOdAkt integer;
  
  mesforod integer;
  mesfordo integer;
  aktrok integer;
  aktmesic integer;
  aktdatum date;
  _idOsoba integer;
begin
  select min(platioddata), max(platidodata) into _od, _do from nucetobdobi;
  rokod = date_part('year', _od);
  rokdo = date_part('year', _do);
  mesicod = date_part('month', _od);
  mesicdo = date_part('month', _do);
  
  if  (_idpracpom > -1) then        -- pokud delame jenom jeden pracovni pomer delame smeny i mimo obdobi
    select aktivniod, idosoba into _odAkt, _idOsoba from ppracpomhlav where idpracpomhlav = _idpracpom;
    rokOdAkt = date_part('year', _odAkt);
    mesicOdAkt = date_part('month', _odAkt);
    
    for aktrok in rokOdAkt..rokod loop
      mesforod = 1;
      mesfordo = 12;
      if (aktrok = rokOdAkt) then
        mesforod = mesicOdAkt;
      end if;  
      if (aktrok = rokod) then
        mesfordo = mesicod - 1;
      end if;
    
      -- a mesice
      for aktmesic in mesforod..mesfordo loop
        if (not pismzdyzamek(aktrok, aktmesic)) then
          -- smeny
          perform pgeneratesmenyforpracpom(_idpracpom, aktrok, aktmesic) where pcantriggerchangeslozku(aktrok, aktmesic, _idOsoba);
        end if;
      end loop;
    end loop;
  end if; 
  
  -- vymazeme nadbytecne
  delete from pmzdsloz where (rok < rokod or (rok = rokod and mesic < mesicod)) or (rok > rokdo or (rok = rokdo and mesic > mesicdo));
  delete from psmeny where (rok > rokdo or (rok = rokdo and mesic > mesicdo));
  
  -- prochazime roky
  for aktrok in rokod..rokdo loop
    mesforod = 1;
    mesfordo = 12;
    if (aktrok = rokod) then
      mesforod = mesicod;
    end if;  
    if (aktrok = rokdo) then
      mesfordo = mesicdo;
    end if;
    
    -- a mesice
    for aktmesic in mesforod..mesfordo loop
      if (not pismzdyzamek(aktrok, aktmesic)) then
        aktdatum = date (aktrok || '-' || aktmesic || '-01');
      
        perform pgeneratemzdslozforpracpomandmesic(idpracpomhlav, aktrok, aktmesic) from ppracpomhlav where
          (_idpracpom = -1 or idpracpomhlav = _idpracpom) and (aktivnido is null or aktdatum <= aktivnido) and 
          (aktivniod is null or date_part('year', aktivniod) < aktrok or (date_part('year', aktivniod) = aktrok and date_part('month', aktivniod) <= aktmesic));
      end if;
    end loop;
  end loop;
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pgeneratemzdslozforpracpom(integer) OWNER TO %firmaRole%;


-- trigger generujici mzdove slozky pri vytvoreni nebo uprave stale mzdove slozky
CREATE OR REPLACE FUNCTION pstalamzdslozupdatemzdsloz()
  RETURNS trigger AS $$
declare
  _rok integer;
  _mesic integer;
begin
  -- vymazeme nadbytecne slozky pro stale slozky
  if (NEW.datumod is not null) then
    _rok = date_part('year', NEW.datumod);
    _mesic = date_part('month', NEW.datumod);
    
    delete from pmzdsloz where idstalamzdsloz = NEW.idstalamzdsloz and (rok < _rok or (rok = _rok and mesic < _mesic)) and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;
  
  if (NEW.datumdo is not null) then
    _rok = date_part('year', NEW.datumdo);
    _mesic = date_part('month', NEW.datumdo);
    
    delete from pmzdsloz where idstalamzdsloz = NEW.idstalamzdsloz and (rok > _rok or (rok = _rok and mesic > _mesic)) and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;

  -- vygenerujeme chybejici slozky
  perform pgeneratemzdslozforpracpom(NEW.idpracpom);
  
  -- nastavime aktualni parametry
  perform pupdatemzdslozfromstalasloz(idmzdsloz, NEW.idstalamzdsloz) from pmzdsloz where idstalamzdsloz = NEW.idstalamzdsloz and pcantriggerchangeslozku(rok, mesic, idosoba);
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pstalamzdslozupdatemzdsloz() OWNER TO %firmaRole%;


-- trigger mazajici mzdove slozky pri smazani stale mzdove slozky
CREATE OR REPLACE FUNCTION pstalamzdslozdeletemzdsloz()
  RETURNS trigger AS $$
begin
  delete from pmzdsloz where idstalamzdsloz = OLD.idstalamzdsloz and pcantriggerchangeslozku(rok, mesic, idosoba);
  
  -- ty co se nesmazali protoze jsou v zamcenym obdobi odvazeme od stale slozky
  update pmzdsloz set idstalamzdsloz = null where idstalamzdsloz = OLD.idstalamzdsloz;

  return OLD;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pstalamzdslozdeletemzdsloz() OWNER TO %firmaRole%;


-- trigger generujici mzdove slozky pri vytvoreni nebo uprave srazky
CREATE OR REPLACE FUNCTION psrazkaupdatemzdsloz()
  RETURNS trigger AS $$
declare
  _rok integer;
  _mesic integer;
  _idpracpom integer;
begin
  -- vymazeme nadbytecne slozky pro srazky
  if (NEW.srazkaod is not null) then
    _rok = date_part('year', NEW.srazkaod);
    _mesic = date_part('month', NEW.srazkaod);
    
    delete from pmzdsloz where idsrazka = NEW.idsrazka and (rok < _rok or (rok = _rok and mesic < _mesic)) and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;
  
  if (NEW.srazkado is not null) then
    _rok = date_part('year', NEW.srazkado);
    _mesic = date_part('month', NEW.srazkado);
    
    delete from pmzdsloz where idsrazka = NEW.idsrazka and (rok > _rok or (rok = _rok and mesic > _mesic)) and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;

  -- vygenerujeme chybejici slozky
  select idpracpomhlav into _idpracpom from ppracpomhlav where idosoba = NEW.idosoba limit 1;
  if (_idpracpom is not null) then 
    perform pgeneratemzdslozforpracpom(_idpracpom);
  end if;
  
  -- nastavime aktualni parametry
  perform pupdatemzdslozfromsrazka(idmzdsloz, NEW.idsrazka) from pmzdsloz where idsrazka = NEW.idsrazka and pcantriggerchangeslozku(rok, mesic, idosoba);
  
  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.psrazkaupdatemzdsloz() OWNER TO %firmaRole%;


-- trigger mazajici mzdove slozky pri smazani srazky
CREATE OR REPLACE FUNCTION psrazkadeletemzdsloz()
  RETURNS trigger AS $$
begin
  delete from pmzdsloz where idsrazka = OLD.idsrazka and pcantriggerchangeslozku(rok, mesic, idosoba);
  
  -- ty co se nesmazali protoze jsou v zamcenym obdobi odvazeme od srazky
  update pmzdsloz set idsrazka = null where idsrazka = OLD.idsrazka;

  return OLD;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.psrazkadeletemzdsloz() OWNER TO %firmaRole%;


-- trigger prenasejici zmeny na ciselniku i na slozky
CREATE OR REPLACE FUNCTION pcismzdslozupdatemzdsloz()
  RETURNS trigger AS $$
begin
  -- neresi zmenu pole naOsobu, je treba osetrit ve scriptu protoze to je slozitejsi
  if (NEW.kod <> OLD.kod or NEW.nazev <> OLD.nazev or NEW.pracovni <> OLD.pracovni or NEW.typSlozkyK <> OLD.typSlozkyK or NEW.skupSlozkyK <> OLD.skupSlozkyK) then
    UPDATE pmzdsloz SET kod = NEW.kod, nazev = NEW.nazev, pracovni = NEW.pracovni, typSlozkyK = NEW.typSlozkyK, skupSlozkyK = NEW.skupSlozkyK
      WHERE idCisMzdSloz = NEW.idCisMzdSloz and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;

  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pcismzdslozupdatemzdsloz() OWNER TO %firmaRole%;


-- trigger odnastavujici datum vypoctu mzdy pri zmene a hlidajici ze se nezmeni slozka v zamcenem obdobi
CREATE OR REPLACE FUNCTION pmzdslozupdatedatumvypoctu()
  RETURNS trigger AS $$
declare
  ZAZNAM record;
  _datumOd date;
  _datumDo date;
  _zamku integer;
begin
  if (tg_op = 'UPDATE') then
    if (OLD.idstalamzdsloz is not null and NEW.idstalamzdsloz is null) then     -- mazame stalou mzdovou slozku - to je ok
      return NEW;
    end if;
    if (OLD.idsrazka is not null and NEW.idsrazka is null) then     -- mazame srazku - to je ok
      return NEW;
    end if;
  end if;

  if (tg_op = 'DELETE') then
    ZAZNAM := OLD;  
  else  
    ZAZNAM := NEW;  
  end if;
  
  _datumOd = date (ZAZNAM.rok || '-' || ZAZNAM.mesic || '-01');
  _datumDo = _datumOd + interval '1 month';
  
  select count(*) into _zamku from wzamky where modulmzd = true and zamekk in ('zamek.polozamceno', 'zamek.zamceno') and
      platioddata < _datumDo and platidodata >= _datumOd;
  if (_zamku > 0) then
    raise exception 'Mzdy v období %/% jsou zamčené a není možno je měnit.', ZAZNAM.rok, ZAZNAM.mesic;
  end if;
  
  if (ZAZNAM.typslozkyk <> 'typSlozky.kopie' or ZAZNAM.skupslozkyk <> 'skupinaSlozky.doba') then
    update pmzdsloz set datumod = null where rok = ZAZNAM.rok and mesic = ZAZNAM.mesic and idosoba = ZAZNAM.idosoba and 
        typslozkyk = 'typSlozky.kopie' and skupslozkyk = 'skupinaSlozky.doba';
  end if;
  
  return ZAZNAM;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pmzdslozupdatedatumvypoctu() OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 270, 't');
