--------------------------------------------------------------------------------
-- Bug 18696 – [WinStrom] Ve výdejce do výroby-změna účtování v hlavičce se nepromítne se do položek
--------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION dpolskladinsertkusovnik()
  RETURNS trigger AS
$BODY$
declare
    _typPohybuK varchar;
    _typZasobyK varchar;
    _idKusovnik integer;
    _iducetobdobi integer;
    _stavNaSklade numeric;
    _sklKarta record;
    _cenik record;
    _sklzapor boolean;
    _idVydejPolSklad integer;
    _idParovanyDoklad integer;
    potKus record;
    _parKusMnoz numeric;
    _i integer;
    _kurz numeric;
    _isCiziMena boolean;
    _idMeny integer;
    _mnozMj numeric;
    _cenaMj numeric;
    _sumZkl numeric;
    _newSumZkl numeric;
    _sumZklMen numeric;
    _idSkladPotKus integer;
    _idProtiUcetDoklad integer;
begin
  -- napriklad pokud se jedna o prevodku mezi sklady nechceme z prijemky vytvaret prevodku
  if (NEW.prevodka = true) then
    return NEW;
  end if;

  -- typem pohybu musi byt prijem
  select typpohybuk into _typPohybuK from ddoklsklad d where d.iddoklsklad = NEW.iddoklsklad;
  if (_typPohybuK <> 'typPohybu.prijem') then
    return NEW;
  end if;

  -- idcenik odkazuje na neco co je soucasti kusovniku.
  select ckus.idkusovnik into _idKusovnik from ckusovnik ckus where ckus.idcenik = NEW.idcenik
    and exists (select 1 from ckusovnik cPot where cPot.idotec = ckus.idkusovnik);
  if (_idKusovnik is null) then
    return NEW;
  end if;

  -- vytvorime nebo nalezneme zparovany doklad skl vydej
  select findparovanydoklsklad(NEW.iddoklsklad, NEW.modul, 'typVazbyDokl.hlavaSklKus') into _idParovanyDoklad;
  if (_idParovanyDoklad is null) then
    select createdoklsklad(NEW.idpolsklad, NEW.iddoklsklad, NEW.modul) into _idParovanyDoklad;
  end if;

  select isDoklSkladMenaCizi(_idParovanyDoklad, NEW.datVyst) into _isCiziMena;
  select getkurzfromdoklad(_idParovanyDoklad, NEW.datVyst) into _kurz;
  select idMeny into _idMeny from dDoklSklad where idDoklSklad = _idParovanyDoklad;

  _i = 0;
  _newSumZkl = 0.0;

  perform putglotxvariable('zurnalTxName', 'rozpadKusovniku');

  -- pro vsechny kusovniky, ktere jsou pod nasim kusovnikem a jsou skladove nebo vyroba
  for potKus in (select * from ckusovnik cPot where cPot.idotec = _idKusovnik) loop
    select * into _cenik from cCenik where idCenik = potKus.idCenik;

    select typZasobyK into _typZasobyK from cCenik cen where cen.idCenik = potKus.idCenik;
    if (_typZasobyK <> 'typZasoby.skladem' and _typZasobyK <> 'typZasoby.vyrobek') then
        _newSumZkl = _newSumZkl + _cenik.nakupcena * potKus.mnoz;
        continue;
    end if;
    _i = _i + 1;

    select findIdUcetniObdobiKDatu(NEW.datVyst) into _iducetobdobi;
    -- vybereme skladovou kartu podle preferovaneho skladu
    select null into _sklKarta;
    _idSkladPotKus = null;

    select getPrefIdSkladu(
	(select idstred from ddoklsklad where iddoklsklad = NEW.iddoklsklad),
	_cenik.idskupzboz, potKus.idcenik) into _idSkladPotKus;

    if (_idSkladPotKus is not null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = _idSkladPotKus and iducetobdobi = _iducetobdobi;
    end if;

    -- sklad karta nebyla nalezena podle preferovaneho skladu, vezmeme sklad stejny jako z vytvarene polozky
    if (_sklKarta is null) then
	select * into _sklKarta from skarty where idcenik = potKus.idcenik and idtypdokl = NEW.idskladu and iducetobdobi = _iducetobdobi;
    end if;

    -- skladovou
    if (_sklKarta is null) then
	raise exception 'Nebyla nalezena skladova karta k polozce ceniku %. Definujte mapovani skladu pro tuto polozku nebo ji pridejte na sklad %',
		_cenik.kod, (select kod from dtypdokl where idtypdokl = NEW.idskladu);
    end if;

    select mnoz into _parKusMnoz from ckusovnik where idkusovnik = _idKusovnik;

   _mnozMj = (potKus.mnoz / _parKusMnoz) * NEW.mnozMj;
   _cenaMj = _sklKarta.prumCenaTuz / _kurz;
   _sumZkl = _mnozMj * _sklKarta.prumCenaTuz;
   _newSumZkl = _newSumZkl + _sumZkl;

   if(_isCiziMena) then
     _sumZklMen = _mnozMj * _cenaMj;
   else
     _sumZklMen = 0.0;
   end if;

    -- TODO doplnit sarze a expirace
    select dgetstavnasklade(_sklKarta.idkarty, NEW.datVyst, -1, NEW.idfirmy, NULL, NULL) into _stavNaSklade;

    -- osetreni zda je povoleny zaporny stav na sklade
    if (_stavNaSklade - _mnozMj < 0) then
        select sklzapor into _sklzapor from nNastav where NEW.datVyst >= PlatiOdData order by PlatiOdData desc limit 1;
        if (_sklzapor is null) then
            select sklzapor into _sklzapor from nNastav where PlatiOdData is null limit 1;
        end if;
        if _sklzapor is null or _sklzapor = false then
            raise exception '0002:sPreporctiSkladKartu: neni povolen zaporny stav skladu';
        end if;
    end if;

    select nextval('seq_dpolsklad'::regclass) into _idVydejPolSklad;
    select idprotiucet into _idProtiUcetDoklad from ddoklsklad where iddoklsklad = _idParovanyDoklad;

    insert into dpolsklad(idPolSklad, idcenik, idskladu, idkarty, datVyst, datUcto, modul, typPolozkyK, idDoklSklad,
        mnozMj, cenaMj, sumZkl, sumZklMen, idZklMdUcet, idZklDalUcet, kopZklMdUcet, kopZklDalUcet, baleniid, mnozBaleni,
        nazev, nazevA, nazevB, nazevC, sarze, expirace, cisRad, ucetni, idStred, idZakazky, idMeny)
    values (_idVydejPolSklad, potKus.idcenik, _sklKarta.idtypdokl, _sklKarta.idkarty, NEW.datVyst, NEW.datUcto, NEW.modul, NEW.typpolozkyk, _idParovanyDoklad,
        _mnozMj, _cenaMj, _sumZkl, _sumZklMen, _idProtiUcetDoklad, NEW.idzklmducet, true, false, NEW.baleniid, NEW.mnozbaleni,
        _cenik.nazev, _cenik.nazevA, _cenik.nazevB, _cenik.nazevC, NULL, NULL, NEW.cisRad * 100 + _i, true,
        NEW.idStred, NEW.idZakazky, _idMeny);

    insert into dvazebtab (castka, idtabA, idtabB, modulA, modulB, storno, typVazbyK)
      values (0.0, NEW.idpolsklad, _idVydejPolSklad, 'SKL', 'SKL', false, 'typVazbyDokl.polozkaSklKus');

  end loop;

  perform removeglotxvariable('zurnalTxName');

  select getkurzfromdoklad(NEW.iddoklsklad, NEW.datvyst) into _kurz;
  _cenaMj = _newSumZkl / NEW.mnozMj / _kurz;

  select isDoklSkladMenaCizi(NEW.iddoklsklad, NEW.datVyst) into _isCiziMena;
  if (_isCiziMena) then
    _sumZklMen = NEW.cenaMj * NEW.mnozMj;
  else
    _sumZklMen = 0.0;
  end if;

  update dpolsklad set sumzkl = _newSumZkl, cenaMj = _cenaMj, sumZklMen = _sumZklMen where idpolsklad = NEW.idpolsklad;

  return NEW;
end;
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dpolskladinsertkusovnik() OWNER TO %firmaRole%;


--------------------------------------------------------------------------------
-- Bug 18738 – [WinStrom] Doplnit druh účtu k 481 a 480
-- Bug 18865 – [WinStrom] Přidat do účtové osnovy účet 417
-- Bug 18737 – [WinStrom] Ukončení platnosti neplatných účtů z účtové osnovy - 118, 128, 138, 658, 659, 674
--------------------------------------------------------------------------------


create or replace function runupgrade()
    returns void as $$
declare
    _idtyporgread integer;
begin
  select idtyporg into _idtyporgread from nnastav limit 1;

  -- sestavy aktualizujeme jen pro cechy
  if (_idtyporgread = 1) then
-- zacatek bloku ceskych podnikatelu


-- Bug 18738 – [WinStrom] Doplnit druh účtu k 481 a 480
UPDATE ustducty SET druhuctuk='druhUctu.aktpasvy' WHERE uuid='CZ_POD_480';
UPDATE ustducty SET druhuctuk='druhUctu.aktpasvy' WHERE uuid='CZ_POD_481';

-- Bug 18865 – [WinStrom] Přidat do účtové osnovy účet 417
INSERT INTO ustducty (lastupdate, kod, nazev, nazeva, nazevb, nazevc, platido, platiod, popis, poznam, show, druhuctuk, saldo, typuctuk, idtyporg, uuid)
 VALUES ('2010-03-25 00:00:00', '417', 'Rozdíly z přeměn společnosti', NULL, NULL, NULL, 9999, 0, NULL, NULL, true, 'druhUctu.pasivni', false, 'typUctu.rozvahovy', 1,
 'CZ_POD_417');

-- Bug 18737 – [WinStrom] Ukončení platnosti neplatných účtů z účtové osnovy - 118, 128, 138, 658, 659, 674
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_118';
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_128';
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_138';
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_658';
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_659';
UPDATE ustducty SET platido=2009 WHERE uuid= 'CZ_POD_674';

-- [5] Ukončení platnosti účtů z účtového rozvrhu [505]
UPDATE uucty
SET iducetobdobido = (SELECT iducetobdobi from nucetobdobi uo where uo.platioddata < '2009-12-31' and (uo.platidodata > '2009-12-31' or uo.platidodata = '2009-12-31'))
FROM ustducty
WHERE uucty.idstducet = ustducty.idstducet AND ustducty.platido = 2009;


-- Sestavy
-- Bug 18866 – [WinStrom] Přidat řádek rozvahy A II. 5
UPDATE usesradky SET cisrad = 81 WHERE IdSesRadky = 56;
UPDATE usesradky SET cisrad = 82 WHERE IdSesRadky = 57;
UPDATE usesradky SET cisrad = 84 WHERE IdSesRadky = 58;
UPDATE usesradky SET cisrad = 85 WHERE IdSesRadky = 59;
UPDATE usesradky SET cisrad = 86, nazev = 'Výsledek hospodaření běžného účet.období (+/-)' WHERE IdSesRadky = 60;
UPDATE usesradky SET cisrad = 89 WHERE IdSesRadky = 61;
UPDATE usesradky SET cisrad = 90 WHERE IdSesRadky = 62;
UPDATE usesradky SET cisrad = 91 WHERE IdSesRadky = 63;
UPDATE usesradky SET cisrad = 95 WHERE IdSesRadky = 64;
UPDATE usesradky SET cisrad = 96 WHERE IdSesRadky = 65;
UPDATE usesradky SET cisrad = 98 WHERE IdSesRadky = 66;
UPDATE usesradky SET cisrad = 103 WHERE IdSesRadky = 67;
UPDATE usesradky SET cisrad = 105 WHERE IdSesRadky = 68;
UPDATE usesradky SET cisrad = 106 WHERE IdSesRadky = 69;
UPDATE usesradky SET cisrad = 107 WHERE IdSesRadky = 70;
UPDATE usesradky SET cisrad = 108 WHERE IdSesRadky = 71;
UPDATE usesradky SET cisrad = 109 WHERE IdSesRadky = 72;
UPDATE usesradky SET cisrad = 110 WHERE IdSesRadky = 73;
UPDATE usesradky SET cisrad = 111 WHERE IdSesRadky = 74;
UPDATE usesradky SET cisrad = 112 WHERE IdSesRadky = 75;
UPDATE usesradky SET cisrad = 113 WHERE IdSesRadky = 76;
UPDATE usesradky SET cisrad = 114 WHERE IdSesRadky = 77;
UPDATE usesradky SET cisrad = 115 WHERE IdSesRadky = 78;
UPDATE usesradky SET cisrad = 117 WHERE IdSesRadky = 79;
UPDATE usesradky SET cisrad = 118 WHERE IdSesRadky = 80;
UPDATE usesradky SET cisrad = 119 WHERE IdSesRadky = 81;
UPDATE usesradky SET cisrad = 121 WHERE IdSesRadky = 82;
UPDATE usesradky SET cisrad = 122 WHERE IdSesRadky = 83;
UPDATE usesradky SET cisrad = 87 WHERE IdSesRadky = 105;
UPDATE usesradky SET cisrad = 120 WHERE IdSesRadky = 106;
UPDATE usesradky SET cisrad = 83 WHERE IdSesRadky = 107;
UPDATE usesradky SET cisrad = 80 WHERE IdSesRadky = 108;
UPDATE usesradky SET cisrad = 88 WHERE IdSesRadky = 111;
UPDATE usesradky SET cisrad = 93 WHERE IdSesRadky = 112;
UPDATE usesradky SET cisrad = 104 WHERE IdSesRadky = 113;
UPDATE usesradky SET cisrad = 116 WHERE IdSesRadky = 114;
UPDATE usesradky SET cisrad = 92 WHERE IdSesRadky = 115;
UPDATE usesradky SET cisrad = 100 WHERE IdSesRadky = 116;
UPDATE usesradky SET cisrad = 102 WHERE IdSesRadky = 117;
UPDATE usesradky SET cisrad = 101 WHERE IdSesRadky = 118;
UPDATE usesradky SET cisrad = 99 WHERE IdSesRadky = 119;
UPDATE usesradky SET cisrad = 97 WHERE IdSesRadky = 120;
UPDATE usesradky SET cisrad = 94 WHERE IdSesRadky = 121;
UPDATE usesradky SET cisrad = 123 WHERE IdSesRadky = 122;
INSERT INTO usesradky (idsesradky, lastUpdate, cisrad, oznaceni, nazev, zjednodusena, hod1, hod2, hod3, hod4, hod5, hod6, idsestavy)
 VALUES (185, '2010-03-29 00:00:00.000', 79, 'P  A   II   5', 'Rozdíly z přeměn společnosti', false, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1);

INSERT INTO usessumace (idsessumace, lastUpdate, prevratznam, idsesradky, idsesradkysum)
 VALUES (379, '2010-03-29 00:00:00.000', false, 110, 185);
 
UPDATE usesstdpred SET druhuctuk = 'druhUctu.aktivni', prevratznam = false WHERE IdSesStdPred = 86;
UPDATE usesstdpred SET druhuctuk = 'druhUctu.aktivni', prevratznam = false WHERE IdSesStdPred = 87;
UPDATE usesstdpred SET jenkladne = true WHERE IdSesStdPred = 133;
INSERT INTO usesstdpred (idsesstdpred, lastUpdate, druhuctuk, cissloup, zpusobvypk, prevratznam, jenkladne, idsesradky, idstducet)
 VALUES (449, '2010-03-29 00:00:00.000', 'druhUctu.pasivni', 1, 'zpusobVypo.stavKon', true, false, 185, (select IdStdUcet from uStdUcty where uuid = 'CZ_POD_417'));

-- konec ceskeho bloku
  end if;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION runupgrade() OWNER TO %firmaRole%;

select runupgrade();

drop function runupgrade();


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 277, 't');
