--------------------------------------------------------------------------------
-- Bug 18909 – [WinStrom] Zustatkova cena udalosti typu castecne a uplne vyrazeni nevstupuje do ucetnictvi
--------------------------------------------------------------------------------

-- pouzivame stejne trigery pro danodpisy, ucetniodpisy a udalosti

-- vytvorime funkce pro triggery udalosti
CREATE OR REPLACE FUNCTION mudalostiinsertucto() RETURNS trigger
    AS $$
begin
  -- odpisy majetku jsou vedeny vzdy v mistni mene, proto za menu
  -- dosazujeme -1 a za sumZklMen 0.0
  execute createOrUpdateObraty(NEW.Ucetni, false, NEW.DatUcto, NEW.idZklMdUcet, NEW.idZklDalUcet,
        -1, NEW.idStred, NEW.sumZkl, 0.0);

  -- u udalosti castecneho nebo uplneho vyrazeni musime zauctovat take zustatek udalosti
  if (NEW.typudalostik in ('typUdal.uplVyr', 'typUdal.casVyr')) then
    execute createOrUpdateObraty(NEW.Ucetni, false, NEW.DatUcto, NEW.idDphMdUcet, NEW.idDphDalUcet,
        -1, NEW.idStred, NEW.sumdph, 0.0);
  end if;

  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.mudalostiinsertucto() OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION mudalostiupdateucto() RETURNS trigger
    AS $$
begin
  -- odpisy majetku jsou vedeny vzdy v mistni mene, proto za menu
  -- dosazujeme -1 a za sumZklMen 0.0
  execute createOrUpdateObraty(OLD.Ucetni, false, OLD.DatUcto, OLD.idZklMdUcet, OLD.idZklDalUcet,
       -1, OLD.idStred, -OLD.sumZkl, 0.0);

  -- pokud byla drive udalost castecne nebo uplne vyrazeni musime ji odebrat z obratu
  if (OLD.typUdalostiK in ('typUdal.uplVyr', 'typUdal.casVyr')) then
    execute createOrUpdateObraty(OLD.Ucetni, false, OLD.DatUcto, OLD.idDphMdUcet, OLD.idDphDalUcet,
        -1, OLD.idStred, -OLD.sumdph, 0.0);
  end if;

  -- odpisy majetku jsou vedeny vzdy v mistni mene, proto za menu
  -- dosazujeme null a za sumZklMen 0.0
  execute createOrUpdateObraty(NEW.Ucetni, false, NEW.DatUcto, NEW.idZklMdUcet, NEW.idZklDalUcet,
       -1, NEW.idStred, NEW.sumZKl, 0.0);

  -- pokud je udalost castecne nebo uplne vyrazeni musime zauctovat jeji zustatkovou cenu
  if (NEW.typUdalostiK in ('typUdal.uplVyr', 'typUdal.casVyr')) then
    execute createOrUpdateObraty(NEW.Ucetni, false, NEW.DatUcto, NEW.idDphMdUcet, NEW.idDphDalUcet,
        -1, NEW.idStred, NEW.sumdph, 0.0);
  end if;

  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.mudalostiupdateucto() OWNER TO %firmaRole%;

CREATE OR REPLACE FUNCTION mudalostideleteucto() RETURNS trigger
    AS $$
begin
  -- odpisy majetku jsou vedeny vzdy v mistni mene, proto za menu
  -- dosazujeme -1 a za sumZklMen 0.0
  execute createOrUpdateObraty(OLD.Ucetni, false, OLD.DatUcto, OLD.idZklMdUcet, OLD.idZklDalUcet,
       -1, OLD.idStred, -OLD.sumZkl, 0.0);

  -- pokud byla drive udalost castecne nebo uplne vyrazeni musime ji odebrat z obratu
  if (OLD.typUdalostiK in ('typUdal.uplVyr', 'typUdal.casVyr')) then
    execute createOrUpdateObraty(OLD.Ucetni, false, OLD.DatUcto, OLD.idDphMdUcet, OLD.idDphDalUcet,
        -1, OLD.idStred, -OLD.sumdph, 0.0);
  end if;

  return OLD;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.mudalostideleteucto() OWNER TO %firmaRole%;

-- odebereme stare trigger z mudalosti
drop trigger mmajetekinsertucto on mudalosti;
drop trigger mmajetekupdateucto on mudalosti;
drop trigger mmajetekdeleteucto on mudalosti;

-- zaregistrujeme nove funkce jako triggery
CREATE TRIGGER mudalostiinsertucto
    BEFORE INSERT ON mudalosti
    FOR EACH ROW
    EXECUTE PROCEDURE mudalostiinsertucto();

CREATE TRIGGER mudalostiupdateucto
    BEFORE UPDATE ON mudalosti
    FOR EACH ROW
    EXECUTE PROCEDURE mudalostiupdateucto();

CREATE TRIGGER mudalostideleteucto
    BEFORE DELETE ON mudalosti
    FOR EACH ROW
    EXECUTE PROCEDURE mudalostideleteucto();

-- update jiz stavajicich udalosti castecneho nebo uplneho vyrazeni udelame rucne
create or replace function runupgrade()
    returns void as $$
declare
  _udalost record;
begin
    for _udalost in (select * from mudalosti) loop
        if (_udalost.typUdalostiK in ('typUdal.uplVyr', 'typUdal.casVyr')) then
            execute createOrUpdateObraty(_udalost.Ucetni, false, _udalost.DatUcto, _udalost.idDphMdUcet, _udalost.idDphDalUcet,
                -1, _udalost.idStred, _udalost.sumdph, 0.0);
        end if;
    end loop;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION runupgrade() OWNER TO %firmaRole%;

select runupgrade();

drop function runupgrade();

---------------------------------------------------------------------
-- Bug 18900 – [winstrom] - Mzdy - číselník mzd.složek - doplnění vazby na výplatní pásku
---------------------------------------------------------------------

ALTER TABLE pcismzdsloz ADD COLUMN ukladatnulove boolean DEFAULT false;

ALTER TABLE pcismzdsloz ADD COLUMN paskamala boolean DEFAULT false;
ALTER TABLE pcismzdsloz ADD COLUMN paskavelka boolean DEFAULT false;
ALTER TABLE pcismzdsloz ADD COLUMN paskapole character varying(255);

---------------------------------------------------------------------
-- Bug 18939 – [winstrom] - Mzdy - srážky - doplnit možnost tvorby interních dokladů
---------------------------------------------------------------------

ALTER TABLE psrazka ADD COLUMN idtypintdokl integer;
ALTER TABLE psrazka ADD CONSTRAINT fkb8d08ebed3979543 FOREIGN KEY (idtypintdokl)
  REFERENCES dtypdokl (idtypdokl) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION;

CREATE INDEX pSrazka_IdTypIntDokl_index ON pSrazka USING btree (IdTypIntDokl);

---------------------------------------------------------------------
-- Bug 17557 – [WinStrom] Aktualizace kalkulačky na rok 2010
---------------------------------------------------------------------

CREATE OR REPLACE FUNCTION pcismzdslozupdatemzdsloz()
  RETURNS trigger AS $$
begin
  -- neresi zmenu pole naOsobu, je treba osetrit ve scriptu protoze to je slozitejsi
  if (NEW.kod <> OLD.kod or NEW.nazev <> OLD.nazev or NEW.pracovni <> OLD.pracovni or NEW.typSlozkyK <> OLD.typSlozkyK or NEW.skupSlozkyK <> OLD.skupSlozkyK or NEW.cisRad <> OLD.cisRad) then
    UPDATE pmzdsloz SET kod = NEW.kod, nazev = NEW.nazev, pracovni = NEW.pracovni, typSlozkyK = NEW.typSlozkyK, skupSlozkyK = NEW.skupSlozkyK, cisRad = NEW.cisRad
      WHERE idCisMzdSloz = NEW.idCisMzdSloz and pcantriggerchangeslozku(rok, mesic, idosoba);
  end if;

  return NEW;
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.pcismzdslozupdatemzdsloz() OWNER TO %firmaRole%;

create or replace function runupgrade()
    returns void as $$
declare
    stat character varying(10);
    pocet integer;
begin
  select a.uuid into stat from nnastav n  left join utyporg u on u.idtyporg = n.idtyporg left join astaty a on a.idstatu = u.idstatu
    where ((select max(platioddata) from nnastav) is null or (select max(platioddata) from nnastav) = platioddata);
  
  -- kalkulacku aktualizujeme jen pro cechy
  if (stat = 'CZ_CZ') then
-- zacatek ceskeho bloku
-- update slozek
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 2;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 3;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 4;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 5;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 6;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 7;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 9;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 10;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 11;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 12;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 13;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 14;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 15;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 16;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 17;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 18;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 19;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 20;
UPDATE pcismzdsloz SET skupslozkyk = 'skupinaSlozky.ostatNahrad', paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 21;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 22;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 23;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 24;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 25;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 26;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 27;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 28;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 29;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 30;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 31;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 32;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 33;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 34;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 35;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 36;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 37;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 38;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 39;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 40;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 41;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 42;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 44;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 45;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 46;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 47;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 48;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 49;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 50;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 51;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 52;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 54;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 55;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 56;
UPDATE pcismzdsloz SET vshodinysvatek = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 61;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 65;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 69;
UPDATE pcismzdsloz SET vsdnykal = true, vsdnyprac = true, vshodiny = true, vscastnahod = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 70;
UPDATE pcismzdsloz SET cisrad = 3166, vsdnykal = true, vsdnyprac = true, vshodiny = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 72;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 73;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 75;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 76;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 77;
UPDATE pcismzdsloz SET nazev = 'Oprava zdrav. pojištění - firma', paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 78;
UPDATE pcismzdsloz SET nazev = 'Oprava základu daně', vszaklmzd = true, vscastmzd = false, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 79;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 80;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 81;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 82;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 83;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 85;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 87;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 88;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 93;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 98;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 99;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 100;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 101;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 103;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 104;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 105;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 106;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 107;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 108;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 109;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 110;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 111;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 112;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 113;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 114;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 115;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 117;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 118;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 119;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 120;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 121;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 122;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 123;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 124;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 125;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 126;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 127;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 128;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 129;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 130;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 131;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 132;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 133;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 134;
UPDATE pcismzdsloz SET cisrad = 8040, skupslozkyk = 'skupinaSlozky.vyplata', paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 135;
UPDATE pcismzdsloz SET cisrad = 8075, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 136;
UPDATE pcismzdsloz SET cisrad = 8076, paskamala = true, paskavelka = true, paskapole = 'castmzd' WHERE IdCisMzdSloz = 137;
UPDATE pcismzdsloz SET cisrad = 8060, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 138;
UPDATE pcismzdsloz SET cisrad = 8080, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 139;
UPDATE pcismzdsloz SET nazev = 'Čistá mzda', cisrad = 8070, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 140;
UPDATE pcismzdsloz SET cisrad = 8090 WHERE IdCisMzdSloz = 141;
UPDATE pcismzdsloz SET cisrad = 8090, vscastmzd = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 142;
UPDATE pcismzdsloz SET cisrad = 8050, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 143;
UPDATE pcismzdsloz SET cisrad = 8060, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 144;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 145;
UPDATE pcismzdsloz SET kod = 'DAŇ -STATUT.ORGÁN', paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 146;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 147;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 150;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 151;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 152;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 153;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 154;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 155;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 157;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 164;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 165;
UPDATE pcismzdsloz SET cisrad = 8000, skupslozkyk = 'skupinaSlozky.vyplata', paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 167;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 171;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 172;
UPDATE pcismzdsloz SET paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 176;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 177;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 178;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 179;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 180;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 181;
UPDATE pcismzdsloz SET nazev = 'Nárok na dovolenou (poměrná část)', cisrad = 1135, skupslozkyk = 'skupinaSlozky.doba', ukladatnulove = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 184;
UPDATE pcismzdsloz SET cisrad = 1138, ukladatnulove = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 185;
UPDATE pcismzdsloz SET cisrad = 1140, ukladatnulove = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 186;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'dnyPrac;hodiny' WHERE IdCisMzdSloz = 188;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 189;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 205;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 216;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 217;
UPDATE pcismzdsloz SET paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 218;
UPDATE pcismzdsloz SET cisrad = 3167, skupslozkyk = 'skupinaSlozky.ostatNahrad', vsdnykal = true, vsdnyprac = true, vshodiny = true, vscastnahod = true, paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 226;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 229;
UPDATE pcismzdsloz SET nazev = 'Odečet dovolené za neomluvenou absenci', pracovni = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 235;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 237;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 238;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 239;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 240;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 241;
UPDATE pcismzdsloz SET cisrad = 8010, skupslozkyk = 'skupinaSlozky.vyplata', paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 242;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 244;
UPDATE pcismzdsloz SET cisrad = 1000 WHERE IdCisMzdSloz = 245;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 247;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 248;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 249;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 250;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 251;
UPDATE pcismzdsloz SET nazev = 'Přeplatek[+] nebo nedoplatek[-] daně z ročního zúčtování', cisrad = 5110, paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 254;
UPDATE pcismzdsloz SET cisrad = 5115 WHERE IdCisMzdSloz = 255;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castMzd' WHERE IdCisMzdSloz = 256;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 257;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 258;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 259;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 260;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 261;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 262;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 263;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 264;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 265;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 266;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 267;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 268;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 269;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 270;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 271;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 272;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 273;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 274;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 275;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 276;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 277;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 278;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 279;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 280;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 281;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 282;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 283;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 284;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 285;
UPDATE pcismzdsloz SET paskamala = true, paskavelka = true, paskapole = 'hodiny;castmzd' WHERE IdCisMzdSloz = 286;
INSERT INTO pcismzdsloz (idcismzdsloz, lastupdate, kod, nazev, show, cisrad, typslozkyk, skupslozkyk, naosobu, vsdatod, vsdatdo, vsdnykal, vsdnyprac, vsdnysvatek, vshodiny, vshodinysvatek, vscastnahod, vscastnaden, vsprocmzd, vszaklmzd, vszakljekracen, vscastmzd, vszmenacastmzd, vspocetmes, vscisdoklnem, vsdoplatzdrpoj, vsprumnadennem, vsprumnahodnem, dnyprac, dnykal, dnysvatek, hodiny, castkahod, castkaden, procmzd, zaklmzd, zakljekracen, castmzd, zmenacastmzd, prumnadennem, prumnahodnem, pracovni, ukladatnulove, paskamala, paskavelka, paskapole)
 VALUES (290, '2010-04-01 00:00:00.000', 'POJISTNÉ PRACOVNÍK', 'Zdravotní a sociální pojištění (celkem za pracovníka)', true, 8020, 'typSlozky.vypocet', 'skupinaSlozky.vyplata', true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, false, 0.0, false, 0.0, 0.0, false, false, true, true, 'hodiny;castmzd');
INSERT INTO pcismzdsloz (idcismzdsloz, lastupdate, kod, nazev, show, cisrad, typslozkyk, skupslozkyk, naosobu, vsdatod, vsdatdo, vsdnykal, vsdnyprac, vsdnysvatek, vshodiny, vshodinysvatek, vscastnahod, vscastnaden, vsprocmzd, vszaklmzd, vszakljekracen, vscastmzd, vszmenacastmzd, vspocetmes, vscisdoklnem, vsdoplatzdrpoj, vsprumnadennem, vsprumnahodnem, dnyprac, dnykal, dnysvatek, hodiny, castkahod, castkaden, procmzd, zaklmzd, zakljekracen, castmzd, zmenacastmzd, prumnadennem, prumnahodnem, pracovni, ukladatnulove, paskamala, paskavelka, paskapole)
 VALUES (291, '2010-04-01 00:00:00.000', 'DAŇOVÝ BONUS', 'Daňový bonus', true, 8035, 'typSlozky.vypocet', 'skupinaSlozky.vyplata', true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, false, 0.0, false, 0.0, 0.0, false, false, true, true, 'hodiny;castmzd');
DELETE FROM pcismzdsloz WHERE IdCisMzdSloz = 86;

PERFORM pg_catalog.setval('seq_pcismzdsloz', 291, true);


-- update inicializacnich radek kalkulacky
-- update radek kalkulacky
DELETE FROM pmzdcalc WHERE IdMzdCalc = 213;
DELETE FROM pmzdcalc WHERE IdMzdCalc = 214;
DELETE FROM pmzdcalc WHERE IdMzdCalc = 627;

UPDATE pmzdcalc SET nazev = 'Celková náhrada za nemoc', cisrad = 380, idmzdslozin = 226 WHERE IdMzdCalc = 215;
UPDATE pmzdcalc SET cisrad = 366 WHERE IdMzdCalc = 221;
UPDATE pmzdcalc SET cisrad = 364 WHERE IdMzdCalc = 222;
UPDATE pmzdcalc SET cisrad = 372 WHERE IdMzdCalc = 223;
UPDATE pmzdcalc SET cisrad = 365 WHERE IdMzdCalc = 256;
UPDATE pmzdcalc SET cisrad = 436 WHERE IdMzdCalc = 307;
UPDATE pmzdcalc SET cisrad = 438 WHERE IdMzdCalc = 308;
UPDATE pmzdcalc SET cisrad = 373 WHERE IdMzdCalc = 310;
UPDATE pmzdcalc SET cisrad = 374 WHERE IdMzdCalc = 311;
UPDATE pmzdcalc SET cisrad = 375, polein = 'castMzd;dnyKal;dnyPrac;hodiny', poleout = 'castMzd;dnyKal;dnyPrac;hodiny' WHERE IdMzdCalc = 328;
UPDATE pmzdcalc SET cisrad = 376, polein = 'castMzd;dnyKal;dnyPrac;hodiny', poleout = 'castMzd;dnyKal;dnyPrac;hodiny' WHERE IdMzdCalc = 329;
UPDATE pmzdcalc SET cisrad = 377, polein = 'castMzd;dnyKal;dnyPrac;hodiny', poleout = 'castMzd;dnyKal;dnyPrac;hodiny' WHERE IdMzdCalc = 330;
UPDATE pmzdcalc SET cisrad = 378, polein = 'castMzd;dnyKal;dnyPrac;hodiny', poleout = 'castMzd;dnyKal;dnyPrac;hodiny' WHERE IdMzdCalc = 331;
UPDATE pmzdcalc SET cisrad = 435 WHERE IdMzdCalc = 358;
UPDATE pmzdcalc SET cisrad = 437 WHERE IdMzdCalc = 359;
UPDATE pmzdcalc SET polein = 'prumNaHodNem;prumNaHodNem', poleout = 'castMzd;castkaHod' WHERE IdMzdCalc = 379;
UPDATE pmzdcalc SET polein = 'prumNaHodNem;prumNaHodNem', poleout = 'castMzd;castkaHod' WHERE IdMzdCalc = 384;
UPDATE pmzdcalc SET cisrad = 381 WHERE IdMzdCalc = 388;
UPDATE pmzdcalc SET cisrad = 370 WHERE IdMzdCalc = 405;
UPDATE pmzdcalc SET nazev = 'Zdrav. pojištění - pracovník', cisrad = 273, idmzdslozin = 103 WHERE IdMzdCalc = 407;
UPDATE pmzdcalc SET cisrad = 272 WHERE IdMzdCalc = 408;
UPDATE pmzdcalc SET cisrad = 369 WHERE IdMzdCalc = 410;
UPDATE pmzdcalc SET cisrad = 382 WHERE IdMzdCalc = 413;
UPDATE pmzdcalc SET cisrad = 383 WHERE IdMzdCalc = 414;
UPDATE pmzdcalc SET cisrad = 384 WHERE IdMzdCalc = 416;
UPDATE pmzdcalc SET cisrad = 385 WHERE IdMzdCalc = 418;
UPDATE pmzdcalc SET cisrad = 386 WHERE IdMzdCalc = 420;
UPDATE pmzdcalc SET cisrad = 389 WHERE IdMzdCalc = 421;
UPDATE pmzdcalc SET cisrad = 390 WHERE IdMzdCalc = 422;
UPDATE pmzdcalc SET cisrad = 404 WHERE IdMzdCalc = 423;
UPDATE pmzdcalc SET cisrad = 394 WHERE IdMzdCalc = 424;
UPDATE pmzdcalc SET cisrad = 397 WHERE IdMzdCalc = 425;
UPDATE pmzdcalc SET cisrad = 387 WHERE IdMzdCalc = 426;
UPDATE pmzdcalc SET cisrad = 388 WHERE IdMzdCalc = 427;
UPDATE pmzdcalc SET cisrad = 391 WHERE IdMzdCalc = 428;
UPDATE pmzdcalc SET cisrad = 396 WHERE IdMzdCalc = 429;
UPDATE pmzdcalc SET cisrad = 403 WHERE IdMzdCalc = 430;
UPDATE pmzdcalc SET cisrad = 398 WHERE IdMzdCalc = 431;
UPDATE pmzdcalc SET cisrad = 399 WHERE IdMzdCalc = 432;
UPDATE pmzdcalc SET cisrad = 400 WHERE IdMzdCalc = 433;
UPDATE pmzdcalc SET cisrad = 401 WHERE IdMzdCalc = 434;
UPDATE pmzdcalc SET cisrad = 402 WHERE IdMzdCalc = 435;
UPDATE pmzdcalc SET kod = 'K VÝPLATĚ', cisrad = 415, idmzdslozout = 140 WHERE IdMzdCalc = 436;
UPDATE pmzdcalc SET cisrad = 395 WHERE IdMzdCalc = 455;
UPDATE pmzdcalc SET cisrad = 360 WHERE IdMzdCalc = 456;
UPDATE pmzdcalc SET cisrad = 361 WHERE IdMzdCalc = 457;
UPDATE pmzdcalc SET cisrad = 362 WHERE IdMzdCalc = 458;
UPDATE pmzdcalc SET polein = 'zaklMzd', idmzdslozin2 = 188 WHERE IdMzdCalc = 482;
UPDATE pmzdcalc SET cisrad = 367 WHERE IdMzdCalc = 488;
UPDATE pmzdcalc SET cisrad = 418 WHERE IdMzdCalc = 514;
UPDATE pmzdcalc SET cisrad = 425 WHERE IdMzdCalc = 516;
UPDATE pmzdcalc SET cisrad = 426 WHERE IdMzdCalc = 517;
UPDATE pmzdcalc SET cisrad = 427 WHERE IdMzdCalc = 518;
UPDATE pmzdcalc SET cisrad = 428 WHERE IdMzdCalc = 519;
UPDATE pmzdcalc SET cisrad = 429 WHERE IdMzdCalc = 520;
UPDATE pmzdcalc SET cisrad = 432 WHERE IdMzdCalc = 521;
UPDATE pmzdcalc SET cisrad = 358 WHERE IdMzdCalc = 522;
UPDATE pmzdcalc SET cisrad = 393 WHERE IdMzdCalc = 523;
UPDATE pmzdcalc SET cisrad = 392 WHERE IdMzdCalc = 524;
UPDATE pmzdcalc SET cisrad = 359 WHERE IdMzdCalc = 530;
UPDATE pmzdcalc SET cisrad = 424 WHERE IdMzdCalc = 537;
UPDATE pmzdcalc SET cisrad = 433 WHERE IdMzdCalc = 538;
UPDATE pmzdcalc SET cisrad = 269 WHERE IdMzdCalc = 540;
UPDATE pmzdcalc SET cisrad = 270 WHERE IdMzdCalc = 541;
UPDATE pmzdcalc SET cisrad = 271 WHERE IdMzdCalc = 542;
UPDATE pmzdcalc SET cisrad = 434 WHERE IdMzdCalc = 550;
UPDATE pmzdcalc SET cisrad = 405 WHERE IdMzdCalc = 577;
UPDATE pmzdcalc SET cisrad = 406 WHERE IdMzdCalc = 578;
UPDATE pmzdcalc SET cisrad = 407 WHERE IdMzdCalc = 579;
UPDATE pmzdcalc SET cisrad = 408 WHERE IdMzdCalc = 580;
UPDATE pmzdcalc SET cisrad = 409 WHERE IdMzdCalc = 581;
UPDATE pmzdcalc SET cisrad = 410 WHERE IdMzdCalc = 582;
UPDATE pmzdcalc SET cisrad = 411 WHERE IdMzdCalc = 583;
UPDATE pmzdcalc SET cisrad = 412 WHERE IdMzdCalc = 585;
UPDATE pmzdcalc SET cisrad = 413 WHERE IdMzdCalc = 586;
UPDATE pmzdcalc SET cisrad = 414 WHERE IdMzdCalc = 587;
UPDATE pmzdcalc SET cisrad = 368 WHERE IdMzdCalc = 595;
UPDATE pmzdcalc SET cisrad = 371 WHERE IdMzdCalc = 596;
UPDATE pmzdcalc SET cisrad = 363 WHERE IdMzdCalc = 625;
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (630, '2010-03-30 00:00:00.000', '17', 'Oprava - Náhrada mzdy za nemoc', true, 379, 1.0, 1.0, 0.0, 'castMzd;dnyKal;dnyPrac;hodiny', 'castMzd;dnyKal;dnyPrac;hodiny', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 72, 226);
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (632, '2010-03-30 00:00:00.000', 'POJISTNÉ PRACOVNÍK', 'Sociální pojištění - pracovník  ', true, 416, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 98, 290);
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (633, '2010-03-30 00:00:00.000', 'POJISTNÉ PRACOVNÍK', 'Zdrav. pojištění - pracovník', true, 417, 1.0, 1.0, 0.0, 'castMzd', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 103, 290);
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (634, '2010-04-01 00:00:00.000', 'PRAC.PRÁVNÍ  PRŮMĚR ', 'Pracovně právní hodinový průměr', true, 431, 1.0, 0.0, 0.0, 'prumNaHodNem', 'castkaHod', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 172, 172);
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, show, cisrad, koeficient, koeficient2, koeficient3, polein, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (635, '2010-04-01 00:00:00.000', 'SOC.POJ.FIRMA ', '---- Základ pro sociální pojištění po akceptování limitu', true, 430, 1.0, 0.0, 0.0, 'zaklMzd', 'zaklMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 201, 229);
INSERT INTO pmzdcalc (idmzdcalc, lastupdate, kod, nazev, popis, show, cisrad, koeficient, koeficient2, koeficient3, polein, polein2, poleout, odhodnoty, dohodnoty, operacek, vyhodnotrocne, summesicu, idmzdcalchlav, idmzdslozin, idmzdslozout)
 VALUES (636, '2010-04-01 00:00:00.000', 'DAŇOVÝ BONUS', 'Daňový bonus', 'nuluji bonus, když je hrubá pod 1/2 minimalní mzdy', true, 423, 1.0, 0.0, 0.0, 'castMzd', '', 'castMzd', 0.0, 0.0, 'mzdCalcOper.plus', false, 0, 1, 109, 291);
UPDATE pmzdcalc SET cisrad = 422 WHERE IdMzdCalc = 454;
UPDATE pmzdcalc SET cisrad = 419 WHERE IdMzdCalc = 495;
UPDATE pmzdcalc SET cisrad = 420 WHERE IdMzdCalc = 496;
UPDATE pmzdcalc SET cisrad = 421 WHERE IdMzdCalc = 628;


PERFORM pg_catalog.setval('seq_pmzdcalc', 636, true);

-- pracovni pomery
-- parametry pro typ prac pom

-- konec ceskeho bloku
  end if; 
end;
$$ LANGUAGE plpgsql;
ALTER FUNCTION runupgrade() OWNER TO %firmaRole%;

select runupgrade();

drop function runupgrade();

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport)
  values (nextval('seq_dbversion'), 278, 't');
