--------------------------------------------------------------------------------
-- Bug 21911 – [winstrom] - ceník - našeptávač - zahrnout kod PLU
-- Bug 24918 – [FlexiBee] Našeptávač pro kasu by měl podporovat i EAN a PLU
--------------------------------------------------------------------------------

DROP FUNCTION IF EXISTS findmatcheditems(character varying, character varying,
  character varying, character varying, character varying, character varying,
  character varying, character varying, integer, integer);


CREATE OR REPLACE FUNCTION findmatcheditems(i_text character varying, i_table character varying,
  i_pkcolumn character varying, i_kodcolumn character varying, i_nazevcolumn character varying, i_nazevL10nColumn character varying,
  i_jineKodyColumns character varying[], i_jineKodyTitles character varying[],
  i_condClause character varying, i_orderClause character varying, i_startIndex integer, i_pageSize integer)
  RETURNS refcursor AS $$
DECLARE
  _text character varying;
  _nazevL10nColumn character varying;
  _projTxt character varying;
  _condEmptyNazevL10n character varying;
  _condNotEmptyNazevL10n character varying;
  _condClause character varying;
  _orderClause character varying;
  _query character varying;
  _limit integer;
  _nalezeno integer;
  _uroven integer;
  _zaznam Record;
  _navratoveHodnoty refcursor;
  i integer;
BEGIN
  DROP TABLE IF EXISTS matcheditems;

  CREATE TEMPORARY TABLE matcheditems (
    id integer PRIMARY KEY,
    kod character varying(255),
    nazev text,
    nazevL10n text,
    txt text,
    uroven integer
  ) WITH (OIDS=FALSE);

  _text = UPPER(i_text);
  _text = replace(_text, '''', '''''');   -- je potreba nahradit ' za ''
  _limit = i_startIndex + i_pageSize;

  IF (i_nazevL10nColumn IS NOT NULL) THEN
    _nazevL10nColumn = i_nazevL10nColumn;
  ELSE
    _nazevL10nColumn = 'null';
  END IF;

  IF (i_condClause IS NOT NULL) THEN
    _condClause = i_condClause || ' AND ';
  ELSE
    _condClause = '';
  END IF;

  IF (i_orderClause IS NOT NULL) THEN
    _orderClause = i_orderClause;
  ELSE
    _orderClause = i_nazevcolumn;
  END IF;

  _projTxt = '(CASE WHEN ' || _nazevL10nColumn || ' IS NOT NULL AND ' || _nazevL10nColumn || ' <> '''' THEN' ||
    ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || _nazevL10nColumn || ', '': '' || ' || _nazevL10nColumn || '), ' || _nazevL10nColumn || ')' ||
    ' ELSE' || 
    ' COALESCE(NULLIF(' || i_kodcolumn || ' || '': '' || ' || i_nazevcolumn || ', '': '' || ' || i_nazevcolumn || '), ' || i_nazevcolumn || ')' ||
    ' END)';
  --RAISE NOTICE '_projTxt is %', _projTxt;
                        
  _condEmptyNazevL10n = '(' || _nazevL10nColumn || ' IS NULL OR ' || _nazevL10nColumn || ' = '''')';
  _condNotEmptyNazevL10n = '(' || _nazevL10nColumn || ' IS NOT NULL AND ' || _nazevL10nColumn || ' <> '''')';

  _uroven = 0;

  -- 1) shoda na alternativní kódy
  IF (i_jineKodyColumns IS NOT NULL) THEN
    FOR i IN 1..array_upper( i_jineKodyColumns, 1 ) LOOP
      _uroven = _uroven + 1;
      _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
          'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
          ' ''' || i_jineKodyTitles[i] || ''' || '' '' || ' || i_jineKodyColumns[i] || ' || '' '' || ' || _projTxt || ', ' ||
          ' ' || _uroven ||
          ' FROM ' || i_table ||
          ' WHERE ' || _condClause ||
          i_jineKodyColumns[i] || ' IS NOT NULL AND ' ||
          ' UPPER(' || i_jineKodyColumns[i] || ') = ''' || _text || '''' ||
          ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
          ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
      --RAISE NOTICE 'Query is %', _query ;
      EXECUTE _query;
    END LOOP;
  END IF;

  -- 2) shoda na kód
  _uroven = _uroven + 1;
  _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
      'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
      ' ' || _projTxt || ', ' ||
      ' ' || _uroven ||
      ' FROM ' || i_table ||
      ' WHERE ' || _condClause ||
      ' UPPER(' || i_kodcolumn || ') = ''' || _text || '''' ||
      ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
      ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
  --RAISE NOTICE 'Query is %', _query ;
  EXECUTE _query;

  SELECT count(*) INTO _nalezeno FROM matcheditems;
  _limit = i_startIndex + i_pageSize - _nalezeno;

  IF (_limit > 0) THEN
    -- 3) shoda na název
    _uroven = _uroven + 1;
    _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
        'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
        ' ' || _projTxt || ', ' ||
        ' ' || _uroven ||
        ' FROM ' || i_table ||
        ' WHERE ' || _condClause ||
        ' ( ' ||
        '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') = ''' || _text || ''') ' ||
        '   OR ' ||
        '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') = ''' || _text || ''') ' ||
        ' ) ' ||
        ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
        ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
    --RAISE NOTICE 'Query is %', _query ;
    EXECUTE _query;

    SELECT count(*) INTO _nalezeno FROM matcheditems;
    _limit = i_startIndex + i_pageSize - _nalezeno;

    IF (_limit > 0) THEN
      -- 4) shodný prefix kódu nebo názvu
      _uroven = _uroven + 1;
      _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
          'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
          ' ' || _projTxt || ', ' ||
          ' ' || _uroven ||
          ' FROM ' || i_table ||
          ' WHERE ' || _condClause ||
          ' ( ' ||
          '   UPPER(' || i_kodcolumn || ') LIKE ''' || _text || '%''' ||
          '   OR ' ||
          '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') LIKE ''' || _text || '%'') ' ||
          '   OR ' ||
          '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') LIKE ''' || _text || '%'') ' ||
          ' ) ' ||
           ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
          ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
      --RAISE NOTICE 'Query is %', _query ;
      EXECUTE _query;

      SELECT count(*) INTO _nalezeno FROM matcheditems;
      _limit = i_startIndex + i_pageSize - _nalezeno;

      IF (_limit > 0) THEN
        -- 5) shodný prefix alternativního kódu
        _uroven = _uroven + 1;
        IF (i_jineKodyColumns IS NOT NULL) THEN
          FOR i IN 1..array_upper( i_jineKodyColumns, 1 ) LOOP
            _uroven = _uroven + 1;
            _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
                'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
                ' ''' || i_jineKodyTitles[i] || ''' || '' '' || ' || i_jineKodyColumns[i] || ' || '' '' || ' || _projTxt || ', ' ||
                ' ' || _uroven ||
                ' FROM ' || i_table ||
                ' WHERE ' || _condClause ||
                i_jineKodyColumns[i] || ' IS NOT NULL AND ' ||
                ' UPPER(' || i_jineKodyColumns[i] || ') LIKE ''' || _text || '%''' ||
                ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
                ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
            --RAISE NOTICE 'Query is %', _query ;
            EXECUTE _query;
          END LOOP;
        END IF;

       IF (_limit > 0) THEN
        -- 6) shodný infix kódu nebo názvu
        _uroven = _uroven + 1;
        _query = 'INSERT INTO matcheditems(id, kod, nazev, nazevL10n, txt, uroven) ' ||
            'SELECT ' || i_pkcolumn || ', ' || i_kodcolumn || ', ' || i_nazevcolumn || ', ' || _nazevL10nColumn || ', ' ||
            ' ' || _projTxt || ', ' ||
            ' ' || _uroven ||
            ' FROM ' || i_table ||
            ' WHERE ' || _condClause ||
            ' ( ' ||
            '   UPPER(' || i_kodcolumn || ') LIKE ''%' || _text || '%''' ||
            '   OR ' ||
            '   (' || _condNotEmptyNazevL10n || ' AND UPPER(' || _nazevL10nColumn || ') LIKE ''%' || _text || '%'') ' ||
            '   OR ' ||
            '   (' || _condEmptyNazevL10n || ' AND UPPER(' || i_nazevcolumn || ') LIKE ''%' || _text || '%'') ' ||
            ' ) ' ||
            ' AND ' || i_pkcolumn || ' NOT IN  (SELECT id FROM matcheditems) ' ||
            ' ORDER BY ' || _orderClause || ' LIMIT ' || _limit || ';';
        --RAISE NOTICE 'Query is %', _query ;
        EXECUTE _query;
       END IF;
      END IF;
    END IF;
  END IF;

  --RETURN QUERY SELECT * FROM matcheditems ORDER BY uroven LIMIT i_pageSize OFFSET i_startIndex;
  OPEN _navratoveHodnoty FOR SELECT * FROM matcheditems ORDER BY uroven LIMIT i_pageSize OFFSET i_startIndex;
  RETURN _navratoveHodnoty;
END;
$$ LANGUAGE plpgsql;

ALTER FUNCTION public.findmatcheditems(i_text character varying, i_table character varying,
  i_pkcolumn character varying, i_kodcolumn character varying, i_nazevcolumn character varying, i_nazevL10nColumn character varying,
  i_jineKodyColumns character varying[], i_jineKodyTitles character varying[],
  i_condClause character varying, i_orderClause character varying, i_startIndex integer, i_pageSize integer) OWNER TO %firmaRole%;



-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 525, 't', %appVersion%, clock_timestamp());