--------------------------------------------------------------------------------
-- Bug 28907 – [WinStrom] Přidat podporu pro webhook a pro sledování změn
--------------------------------------------------------------------------------

create table changelog (
    seq bigserial primary key,

    tabulka character varying(255) not null,
    modul character varying(255),
    id integer not null,
    operace character varying(1) not null,
    uzivatel character varying(50),

    extids character varying(127)[]
);

alter table changelog owner to %admin%;
grant select on table changelog to %firmaRole%;

CREATE INDEX changelog_seq_index ON changelog USING btree (seq);
CREATE INDEX changelog_tabulka_modul_index ON changelog USING btree (tabulka, modul);
CREATE INDEX changelog_operace_index ON changelog USING btree (operace);

CREATE OR REPLACE FUNCTION logchanges() RETURNS trigger AS $$
    if {$TG_table_name == "wextid"} {
        if {$TG_op == "DELETE"} {
            return [array get OLD]
        } else {
            return [array get NEW]
        }
    }

    spi_exec "SELECT pg_attribute.attname AS pk
        FROM pg_index, pg_class, pg_attribute
        WHERE
          pg_class.oid = '[ quote $TG_table_name ]'::regclass AND
          indrelid = pg_class.oid AND
          pg_attribute.attrelid = pg_class.oid AND
          pg_attribute.attnum = any(pg_index.indkey)
          AND indisprimary"

    set modul null
    if {$TG_op == "INSERT" || $TG_op == "UPDATE"} {
        set pkval [ quote $NEW([ quote $pk ]) ]
        if {[info exists NEW(modul)]} {
            set modul '[ quote $NEW(modul) ]'
        }
    } else {
        set pkval [ quote $OLD([ quote $pk ]) ]
        if {[info exists OLD(modul)]} {
            set modul '[ quote $OLD(modul) ]'
        }
    }

    spi_exec "SELECT session_user AS user_name"
    set user_dollar_idx [string first \$ $user_name] 
    if {$user_dollar_idx != -1} {
      incr user_dollar_idx
      set user_name "[string range $user_name $user_dollar_idx end]" 
    }

    set operation "[string range $TG_op 0 0]"
    if {$TG_op == "INSERT"} {
        spi_exec "INSERT INTO changelog(tabulka, modul, id, operace, uzivatel)
            VALUES ('[ quote $TG_table_name ]',
                $modul,
                '[ quote $pkval ]',
                '[ quote $operation ]',
                '[ quote $user_name ]')"
    } elseif {$TG_op == "UPDATE" || $TG_op == "DELETE"} {
        set extid null

        if {[info exists OLD(kod)]} {
            append all_extids 'code:[ quote $OLD(kod) ]'
        }

        spi_exec "select attname AS fk from pg_attribute where attrelid = 'wextid'::regclass and attnum in (select conkey\[1\] from pg_constraint where conrelid = 'wextid'::regclass and confrelid = '[ quote $TG_table_name ]'::regclass)" {
            spi_exec "select extid from wextid where $fk = $pkval" {
                if {[info exists all_extids] && [string length $all_extids] > 0} {
                  append all_extids ","
                }
                append all_extids '[ quote $extid ]'
            }
        }

        if {[info exists all_extids] && [string length $all_extids] > 0} {
            set extid "array\[$all_extids\]"
        }

        spi_exec "INSERT INTO changelog(tabulka, modul, id, operace, uzivatel, extids)
            VALUES ('[ quote $TG_table_name ]',
                $modul,
                '[ quote $pkval ]',
                '[ quote $operation ]',
                '[ quote $user_name ]',
                $extid)"
    }

    if {$TG_op == "DELETE"} {
        return [array get OLD]
    } else {
        return [array get NEW]
    }
$$ LANGUAGE pltcl VOLATILE SECURITY DEFINER;

alter function logchanges() owner to %admin%;


--------------------------------------------------------------------------------
--------------------------------------------------------------------------------


CREATE OR REPLACE FUNCTION create_or_drop_changes_triggers(docreate boolean)
  RETURNS void AS
$BODY$
BEGIN
  IF docreate THEN
    PERFORM create_or_drop_ucto_changes_triggers(true);
    PERFORM create_or_drop_majetek_changes_triggers(true);
    PERFORM create_or_drop_mzdy_changes_triggers(true);
  ELSE
    PERFORM create_or_drop_ucto_changes_triggers(false);
    PERFORM create_or_drop_majetek_changes_triggers(false);
    PERFORM create_or_drop_mzdy_changes_triggers(false);
  END IF;
END;
$BODY$
LANGUAGE 'plpgsql' VOLATILE SECURITY DEFINER;

ALTER FUNCTION create_or_drop_changes_triggers(docreate boolean) OWNER TO %admin%;
GRANT EXECUTE ON FUNCTION create_or_drop_changes_triggers(docreate boolean) TO %firmaRole%;


CREATE OR REPLACE FUNCTION exist_changes_triggers()
  RETURNS boolean AS
$BODY$
DECLARE
  tgcount integer;
BEGIN
  SELECT count(*) INTO tgcount FROM pg_catalog.pg_trigger WHERE tgname LIKE '%changes';

  IF (tgcount > 0) THEN
    RETURN true;
  ELSE
    RETURN false;
  END IF;
END;
$BODY$
LANGUAGE 'plpgsql' VOLATILE;

ALTER FUNCTION exist_changes_triggers() OWNER TO %admin%;
GRANT EXECUTE ON FUNCTION exist_changes_triggers() TO %firmaRole%;


-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 613, 't', %appVersion%, clock_timestamp());
