--------------------------------------------------------------------------------
-- Bug 31689 – [WinStrom] Inventura skladu
--------------------------------------------------------------------------------

alter table sinventura add column idsklad integer;
alter table sinventura add constraint sInventura_idSklad FOREIGN KEY (idSklad)
        REFERENCES dBsp (idBsp)
        ON UPDATE NO ACTION ON DELETE NO ACTION;
CREATE INDEX sInventura_IdSklad_index ON sInventura USING btree (IdSklad);

alter table spolinventura add column idsklad integer;
alter table spolinventura add constraint spolInventura_idSklad FOREIGN KEY (idSklad)
        REFERENCES dBsp (idBsp)
        ON UPDATE NO ACTION ON DELETE NO ACTION;
CREATE INDEX sPolInventura_IdSklad_index ON sPolInventura USING btree (IdSklad);

alter table spolinventura add column idcenik integer;
alter table spolinventura add constraint spolInventura_idCenik FOREIGN KEY (idCenik)
        REFERENCES cCenik (idCenik)
        ON UPDATE NO ACTION ON DELETE NO ACTION;
CREATE INDEX sPolInventura_IdCenik_index ON sPolInventura USING btree (IdCenik);

CREATE OR REPLACE FUNCTION inventuraAktualizujMnozMjKarta(_idInventury integer)
  RETURNS void AS
$BODY$    
declare
  _zaznam record;
  _stavMj numeric(19,6);
  _idUcetObd integer;
  _datum date;
begin

  select datZahaj into _datum from sInventura where idInventura = _idInventury;
  select idUcetObdobi into _iducetobd from nUcetObdobi where platiOdData <= _datum and platiDoData >= _datum;  

  for _zaznam in select * from sPolInventura where idInventury = _idInventury loop
    select max(k.pocatMj) + coalesce(sum(case when d.typpohybuk = 'typPohybu.prijem' then mnozMj else -mnozMj end), 0.0) into _stavMJ
      from skarty k 
      left join dpolsklad p on k.idkarty = p.idkarty and p.storno = false and p.datVyst <= _datum 
      left join ddoklsklad d on p.iddoklsklad = d.iddoklsklad
      where k.iducetobdobi = _iducetobd and k.idskladu = _zaznam.idSklad and k.idcenik = _zaznam.idCenik 
      group by k.idkarty;
    
    if(_zaznam.mnozMjKarta <> _stavMj) then
      update sPolInventura set mnozMjKarta = _stavMj where idpolinventura = _zaznam.idpolinventura;
    end if;

  end loop;

end;    
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION inventuraAktualizujMnozMjKarta(integer) OWNER TO %firmaRole%;

-- zvlneni inventury
alter table spolinventura add column mnozMjRealVlna2 numeric(19,6);
alter table spolinventura add column mnozMjReal2Vlna2 numeric(19,6);
alter table spolinventura add column mnozMjReal3Vlna2 numeric(19,6);

alter table spolinventura add column mnozMjRealVlna3 numeric(19,6);
alter table spolinventura add column mnozMjReal2Vlna3 numeric(19,6);
alter table spolinventura add column mnozMjReal3Vlna3 numeric(19,6);

alter table spolinventura add column mnozMjRealVlna4 numeric(19,6);
alter table spolinventura add column mnozMjReal2Vlna4 numeric(19,6);
alter table spolinventura add column mnozMjReal3Vlna4 numeric(19,6);

-- na martinovo doporuceni predvleno do zasoby
alter table spolinventura add column mnozMjRealVlna5 numeric(19,6);
alter table spolinventura add column mnozMjReal2Vlna5 numeric(19,6);
alter table spolinventura add column mnozMjReal3Vlna5 numeric(19,6);

alter table spolinventura add column mnozMjRealVlna6 numeric(19,6);
alter table spolinventura add column mnozMjReal2Vlna6 numeric(19,6);
alter table spolinventura add column mnozMjReal3Vlna6 numeric(19,6);

--------------------------------------------------------------------------------
-- Bug 31839 – [WinStrom] - Fifo - špatné ceny na výdejce po změně ceny na příjemce
--------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION sfifocenamj(idpohyb integer, iddokl integer, cenamjprijem numeric(19,6))
  RETURNS void AS
$BODY$  
declare  
	_typPohybuk character varying(255);
         _pouzitaPrijemka integer;
        _idPolSklad integer;
        _polSklad record;
        _cenaMj numeric(19,6);
        _kurzPrijem numeric(19,6);
        _kurzVydej numeric(19,6);
        _sumZkl numeric(19,6);
        _sumZklMen numeric(19,6);
        _vydejCiziMena boolean;
        _prijemCiziMena boolean;
        _datVystPrijem date;
begin  
	select typpohybuk into _typPohybuk from ddoklsklad where iddoklsklad = iddokl;	
	if (_typPohybuk = 'typPohybu.prijem') then
	        select datVyst into _datVystPrijem from ddoklsklad where iddoklsklad = iddokl;
                select getkurzfromdoklad(iddokl, _datVystPrijem) into _kurzPrijem;
                _cenaMj = cenamjprijem * _kurzPrijem;
                --pokud změna ceny na příjemce, tak změním dle vazeb na výdejkách 
         	for _idpolsklad in select idpolskladvydej from sfifovazby where idpolskladprijem = idpohyb loop
                  select * into _polSklad from dPolSklad where idPolSklad = _idPolSklad;
                  if(not _polSklad.cenyRucne) then

                    select getkurzfromdoklad(_polSklad.idDoklSklad, _polSklad.datVyst) into _kurzVydej;
                    select isdoklskladmenacizi(_polSklad.idDoklSklad, _polSklad.datVyst) into _vydejCiziMena;

                    select coalesce(sum(case when ps.mnozMj = fv.kusu then ps.sumZkl else ps.cenaMj * fv.kusu end), 0.0) into _sumZkl from dpolsklad ps join sfifovazby fv 
                      on ps.idpolsklad = fv.idpolskladprijem
                      where idpolskladvydej = _idPolSklad;

                    if(_vydejCiziMena = true) then
                      _sumZklMen = _sumZkl / _kurzVydej ;
                      _cenaMj = _sumZklMen / _polSklad.mnozMj;
                    else
                      _sumZklMen = 0.0;
                      _cenaMj = _sumZkl / _polSklad.mnozMj;
                    end if;
                  
                    update dpolsklad set 
                      cenamj = _cenaMj,
                      cenaMjPoriz = _cenaMj,
                      sumZkl = _sumZkl,
                      sumZklMen = _sumZklMen 
                      where idpolsklad = _idPolSklad;
                    execute sprepoctisumydokladu(_polSklad.idDoklSklad);
                  end if;
         	end loop;
		--update dpolsklad set cenamj = cenamjprijem where idpolsklad = (select idpolskladvydej from sfifovazby where idpolskladprijem = idpohyb); 
         end if;
end;  
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION sfifocenamj(integer, integer, numeric(19,6)) OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 672, 't', %appVersion%, clock_timestamp());
