---------------------------------------------------------------------------------------------------
-- Bug 41665 - Vzniká problém při prodeji s šaržemi, jsou-li zakombinovány i rezervace (Supellex) 
---------------------------------------------------------------------------------------------------

-- Function: dgetstavnasklade(integer, date, integer, integer, character varying, date)
-- DROP FUNCTION dgetstavnasklade(integer, date, integer, integer, character varying, date);
CREATE OR REPLACE FUNCTION dgetstavnasklade(i_skladkartaid integer, i_datum date, i_polskladid integer, i_firmaid integer, i_sarze character varying, i_expirace date, i_typpohybuK character varying)
  RETURNS numeric AS
$BODY$ 
declare 
  _sklad integer; 
  _cenik integer; 
  _stavMj numeric(19,6); 
  _stavMjCelkem numeric(19,6);
  _stavMjOstatni numeric(19,6); 
  _stavMjOstatniPoRez numeric(19,6);
  _firmaRezerMj numeric(19,6); 
  _celkemRezerMj numeric(19,6); 
begin 
  SELECT dgetstavnasklade(i_skladkartaid, i_datum, i_polskladid, i_sarze, i_expirace, i_typPohybuK) INTO _stavMj; 
  SELECT dgetstavnasklade(i_skladkartaid, i_datum, i_polskladid, null, null, i_typPohybuK) INTO _stavMjCelkem; 

  -- vymazeme jiz neplatne rezervace 
  delete from srezervace where datumdo is not null and datumdo < date(now()); 
  -- nacteme si info ze skladove karty 
  SELECT idCenik, idSkladu INTO _cenik, _sklad FROM sKarty WHERE idKarty = i_skladkartaid; 
  -- zjistime kolik je celkem rezervovano - od/do ignorujeme (bug 25844, 25789), muselo by se zohlednovat uz pri plneni pole skladmj a nebo toto pole idealne vyhodit
  select coalesce(sum(skladmj), 0) into _celkemRezerMj from srezervace where idcenik = _cenik and idsklad = _sklad;
   
  IF (i_firmaid > 0) THEN 
    -- zjistime kolik ma firma rezervovano 
    select coalesce(sum(skladmj), 0) into _firmaRezerMj from srezervace where idfirmy = i_firmaid and idcenik = _cenik and idsklad = _sklad; 
  ELSE 
    _firmaRezerMj := 0; 
  END IF; 
   
    -- spocteme kolik mu muzeme dat 
  -- stav na skladech bez stavu s konkrétní šarží a expirací
  _stavMjOstatni := _stavMjCelkem - _stavMj;
  -- kolik zůstane na ostatních skladových kartách pro započtení rezervací
  _stavMjOstatniPoRez := _stavMjOstatni - _celkemRezerMj + _firmaRezerMj ;

  -- je možné uspokojit rezervace z ostatních skladových karet
  if (_stavMjOstatniPoRez >= 0) then
	-- chceme vrátit _stavMj;
  else
       -- rezervace musíme uspokojit i ze skladové karty, která se týká aktuální šarže a expirace ->
       -- od stavu odečteme to, kolik nám ještě zbývá uspokojit z rezervovaného množství
	_stavMj := _stavMj - @ _stavMjOstatniPoRez;
  end if;
--  _stavMj := minValue(_stavMj, maxValue(_stavMj - _celkemRezerMj, 0) + _firmaRezerMj); 
   
  RETURN _stavMj; 
end 
$BODY$
  LANGUAGE 'plpgsql' VOLATILE
  COST 100;
ALTER FUNCTION dgetstavnasklade(integer, date, integer, integer, character varying, date, character varying) OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 893, 't', %appVersion%, clock_timestamp());