-------------------------------------------------------------------------------------------------------
-- Bug 44433 - Plně automatické rezervace - rezervované množství je příliš velké
-------------------------------------------------------------------------------------------------------

-- Funkce aktualizujici rezervaci pro obchodni polozku
CREATE OR REPLACE FUNCTION rezervujPolObch(_idCenik integer, _idSklad integer, _idPolObch integer, _mj numeric)
  RETURNS void AS $$
declare
  polObch record;
  _mnoz numeric(19,6);
  _idUcetObd integer;
  _rezer record;
  _idFirma integer;
  _idUziv integer;
  _stav varchar(50);
  _povolenyStav boolean;
begin
  
  -- je-li  nastaveno, nechceme spouštět (nastavuje se ve fci srezervujzprijemky - ta sama si updatuje záznam v srezervace)
  if (getglotxvariable('rezerDisableTrigger') is not null) then 
      return; 
  end if; 
  
  select * into _rezer from srezervace where idPolObch = _idPolObch and idCenik = _idCenik and idSklad = _idSklad;
  
  _mnoz = _mj;
  if _rezer.idrezervace is not null then
    _mnoz = _mnoz + _rezer.mnozstvi;
  end if;
  
  if _mnoz > 0 then             -- pokud ma neco byt zarezervovane
    select * into polObch from dPolObch where idPolObch = _idPolObch;
    
    if _rezer.idrezervace is null then      -- pokud rezervace neexistuje vytvorime ji
      select stavUzivK into _stav from dDoklObch where idDoklObch = polObch.idDoklObch;   
      _povolenyStav := _stav is null or (_stav <> 'stavDoklObch.hotovo' and _stav <> 'stavDoklObch.vydano'  and _stav <> 'stavDoklObch.storno' );
      if(_povolenyStav) then
        select idFirmy, idUziv into _idFirma, _idUziv from dDoklObch where idDoklObch = polObch.idDoklObch;
      
        insert into srezervace (lastupdate, idpolobch, iduziv, idfirmy, idcenik, idsklad, mnozstvi, datumod)
              values (now(), _idPolObch, _idUziv, _idFirma, _idCenik, _idSklad, _mnoz, date_trunc('minute', now()));
      end if;
    else
      update srezervace set mnozstvi = _mnoz where idrezervace = _rezer.idRezervace;
    end if;
  else
    if _rezer.idrezervace is not null then    -- pokud rezervace byt nema a je smazeme ji
      delete from srezervace where idrezervace = _rezer.idRezervace;
    end if;
  end if;
end; 
$$ LANGUAGE plpgsql;
ALTER FUNCTION public.rezervujPolObch(integer, integer, integer, numeric) OWNER TO %firmaRole%;

-- zvyseni verze databaze
insert into dbversion(iddbversion, dbversion, needreimport, appversion, upgradetime)
  values (nextval('seq_dbversion'), 973, 't', %appVersion%, clock_timestamp());
